@@ -3,6 +3,8 @@ VERSION="$1"
 sudo xcode-select -s /Applications/Xcode.app/
 
 SIGNER="Developer ID Application: Meltytech, LLC (Y6RX44QG2G)"
+find ~/Desktop/Shotcut.app -type d -name __pycache__ -exec rm -r {} \+
+find ~/Desktop/Shotcut.app/Contents -name '*.o' -exec rm {} \;
 find ~/Desktop/Shotcut.app/Contents/lib -type f -exec codesign --options=runtime -v -s "$SIGNER" {} \;
 find ~/Desktop/Shotcut.app/Contents/Frameworks -type f -exec codesign --options=runtime -v -s "$SIGNER" {} \;
 find ~/Desktop/Shotcut.app/Contents/PlugIns -type f -exec codesign --options=runtime -v -s "$SIGNER" {} \;
@@ -22,12 +24,12 @@ mv ~/Desktop/Shotcut.app $TMP
 ln -s /Applications $TMP
 cp ../COPYING $TMP
 rm ~/Desktop/shotcut-macos-${VERSION}.dmg
-hdiutil create -srcfolder $TMP -volname Shotcut -format UDBZ -size 600m \
+hdiutil create -srcfolder $TMP -volname Shotcut -format UDBZ -size 800m \
   ~/Desktop/shotcut-macos-${VERSION}.dmg
 rm -rf $TMP
 
 ./notarize.sh ~/Desktop/shotcut-macos-${VERSION}.dmg
+./staple.sh ~/Desktop/shotcut-macos-${VERSION}.dmg
 
-echo wait for the e-mail from Apple and then run:
-echo ./staple.sh ~/Desktop/shotcut-macos-${VERSION}.dmg
+echo Now run:
 echo sudo xcode-select -s /Library/Developer/CommandLineTools
