@@ -626,24 +626,44 @@ void MoveClipCommand::redo()
     QVector<Mlt::Producer> producers;
     QVector<QUuid> uuids;
 
-    // First, save each clip and remove it
+    // First, save each clip and uuid
     for (auto &clip : m_clips) {
+        uuids.append(clip.uuid);
+        auto info = m_model.getClipInfo(clip.trackIndex, clip.clipIndex);
+        if (info && info->producer && info->producer->is_valid() && info->cut) {
+            producers.append(info->producer);
+        } else {
+            LOG_ERROR() << "Unable to find clip to move" << clip.trackIndex << clip.clipIndex;
+            return;
+        }
+    }
+
+    // Next, remove each clip
+    for (auto &clip : m_clips) {
+        // Need to look up each one by UUID because indexes will change as clips are removed and
+        // some clips may be removed due to ripple.
         int trackIndex, clipIndex;
         auto info = m_model.findClipByUuid(clip.uuid, trackIndex, clipIndex);
         if (info && info->producer && info->producer->is_valid() && info->cut) {
-            producers.append(info->producer);
             if (m_ripple)
                 m_model.removeClip(trackIndex, clipIndex, m_rippleAllTracks);
             else
                 m_model.liftClip(trackIndex, clipIndex);
         } else {
-            LOG_ERROR() << "Unable to find clip to move" << trackIndex << clipIndex;
-            return;
+            // This can happen with ripple since a clip my be removed due to ripple
+            if (!m_ripple) {
+                LOG_ERROR() << "Unable to find clip to move" << trackIndex << clipIndex;
+                return;
+            }
         }
     }
 
-    // Then, place each clip in the new location
+    // Finally, place each clip in the new location
     for (auto &clip : m_clips) {
+        if (producers.size() == 0) {
+            LOG_ERROR() << "Missing producer in move command" << clip.trackIndex << clip.clipIndex;
+            return;
+        }
         Mlt::Producer &producer = producers.front();
         int newTrackIndex = qBound(0, clip.trackIndex + m_trackDelta,
                                    qMax(int(m_model.trackList().size()) - 1, 0));
@@ -701,6 +721,9 @@ bool MoveClipCommand::mergeWith(const QUndoCommand *other)
             || that->m_ripple != m_ripple || that->m_rippleAllTracks != m_rippleAllTracks
             || that->m_rippleMarkers != m_rippleMarkers)
         return false;
+    if (that->m_undoHelper.affectedTracks() != m_undoHelper.affectedTracks()) {
+        return false;
+    }
     auto thisIterator = m_clips.begin();
     auto thatIterator = that->m_clips.begin();
     while (thisIterator != m_clips.end() && thatIterator != that->m_clips.end()) {
@@ -1648,6 +1671,7 @@ UpdateCommand::UpdateCommand(TimelineDock &timeline, int trackIndex, int clipInd
     , m_isFirstRedo(true)
     , m_undoHelper(*timeline.model())
     , m_ripple(Settings.timelineRipple())
+    , m_rippleAllTracks(Settings.timelineRippleAllTracks())
 {
     setText(QObject::tr("Change clip properties"));
     m_undoHelper.recordBeforeState();
@@ -1657,6 +1681,7 @@ void UpdateCommand::setXmlAfter(const QString &xml)
 {
     m_xmlAfter = xml;
     m_ripple = Settings.timelineRipple();
+    m_rippleAllTracks = Settings.timelineRippleAllTracks();
 }
 
 void UpdateCommand::setPosition(int trackIndex, int clipIndex, int position)
@@ -1678,8 +1703,8 @@ void UpdateCommand::redo()
         m_undoHelper.recordBeforeState();
     Mlt::Producer clip(MLT.profile(), "xml-string", m_xmlAfter.toUtf8().constData());
     if (m_ripple) {
-        m_timeline.model()->removeClip(m_trackIndex, m_clipIndex, false);
-        m_timeline.model()->insertClip(m_trackIndex, clip, m_position, false, false);
+        m_timeline.model()->removeClip(m_trackIndex, m_clipIndex, m_rippleAllTracks);
+        m_timeline.model()->insertClip(m_trackIndex, clip, m_position, m_rippleAllTracks, false);
     } else {
         m_timeline.model()->liftClip(m_trackIndex, m_clipIndex);
         m_timeline.model()->overwrite(m_trackIndex, clip, m_position, false);
@@ -1692,7 +1717,7 @@ void UpdateCommand::undo()
     LOG_DEBUG() << "trackIndex" << m_trackIndex << "clipIndex" << m_clipIndex << "position" <<
                 m_position;
     m_undoHelper.undoChanges();
-    m_timeline.emitSelectedFromSelection();
+    m_timeline.setSelection(QList<QPoint>() << QPoint(m_clipIndex, m_trackIndex));
     m_isFirstRedo = false;
 }
 
@@ -1715,12 +1740,21 @@ void DetachAudioCommand::redo()
 {
     LOG_DEBUG() << "trackIndex" << m_trackIndex << "clipIndex" << m_clipIndex << "position" <<
                 m_position;
-    TimelineSelectionSilencer selectionSilencer(m_timeline);
     Mlt::Producer audioClip(MLT.profile(), "xml-string", m_xml.toUtf8().constData());
     Mlt::Producer videoClip(MLT.profile(), "xml-string", m_xml.toUtf8().constData());
+    int groupNumber = -1;
     if (audioClip.is_valid() && videoClip.is_valid()) {
         auto model = m_timeline.model();
 
+        // Save the group number if it exists
+        {
+            auto videoClipInfo = model->getClipInfo(m_trackIndex, m_clipIndex);
+            if (videoClipInfo && videoClipInfo->cut
+                    && videoClipInfo->cut->property_exists(kShotcutGroupProperty)) {
+                groupNumber = videoClipInfo->cut->get_int(kShotcutGroupProperty);
+            }
+        }
+
         // Disable audio on the video clip.
         videoClip.set("astream", -1);
         videoClip.set("audio_index", -1);
@@ -1793,23 +1827,18 @@ void DetachAudioCommand::redo()
             model->overwrite(m_targetTrackIndex, audioClip, m_position, false);
             // Replace the original clip with the video only clip
             model->overwrite(m_trackIndex, videoClip, m_position, false);
-            // Put the clips in a group
-            int groupNumber = getUniqueGroupNumber(*model);
-            int audioClipIndex = model->clipIndex(m_targetTrackIndex, m_position);
-            auto audioClipInfo = model->getClipInfo(m_targetTrackIndex, audioClipIndex);
-            if (audioClipInfo && audioClipInfo->cut) {
-                audioClipInfo->cut->set(kShotcutGroupProperty, groupNumber);
-            }
-            auto videoClipInfo = model->getClipInfo(m_trackIndex, m_clipIndex);
-            if (videoClipInfo && videoClipInfo->cut) {
-                videoClipInfo->cut->set(kShotcutGroupProperty, groupNumber);
+            // Restore the video clip group
+            if (groupNumber >= 0) {
+                auto videoClipInfo = model->getClipInfo(m_trackIndex, m_clipIndex);
+                if (videoClipInfo && videoClipInfo->cut) {
+                    videoClipInfo->cut->set(kShotcutGroupProperty, groupNumber);
+                }
             }
             m_undoHelper.recordAfterState();
             QModelIndex modelIndex = model->makeIndex(m_trackIndex, m_clipIndex);
             emit model->dataChanged(modelIndex, modelIndex,
                                     QVector<int>() << MultitrackModel::AudioIndexRole << MultitrackModel::GroupRole);
-            m_timeline.setSelection(QList<QPoint>() << QPoint(m_clipIndex,
-                                                              m_trackIndex) << QPoint(audioClipIndex, m_targetTrackIndex));
+            m_timeline.setSelection(QList<QPoint>() << QPoint(m_clipIndex, m_trackIndex));
         }
     }
 }
@@ -1818,7 +1847,6 @@ void DetachAudioCommand::undo()
 {
     LOG_DEBUG() << "trackIndex" << m_trackIndex << "clipIndex" << m_clipIndex << "position" <<
                 m_position;
-    TimelineSelectionSilencer selectionSilencer(m_timeline);
     auto model = m_timeline.model();
     m_undoHelper.undoChanges();
     if (m_trackAdded) {
