@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015-2022 Meltytech, LLC
+ * Copyright (c) 2015-2023 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -38,7 +38,7 @@ UndoHelper::UndoHelper(MultitrackModel &model)
 void UndoHelper::recordBeforeState()
 {
 #ifdef UNDOHELPER_DEBUG
-    debugPrintState();
+    debugPrintState("Before state");
 #endif
     m_state.clear();
     m_clipsAdded.clear();
@@ -50,7 +50,10 @@ void UndoHelper::recordBeforeState()
 
         for (int j = 0; j < playlist.count(); ++j) {
             QScopedPointer<Mlt::Producer> clip(playlist.get_clip(j));
-            QUuid uid = MLT.ensureHasUuid(*clip);
+            QUuid uid = MLT.ensureHasUuid(clip->parent());
+            if (clip->is_blank()) {
+                uid = MLT.ensureHasUuid(*clip);
+            }
             m_insertedOrder << uid;
             Info &info = m_state[uid];
             if (!(m_hints & SkipXML))
@@ -62,6 +65,9 @@ void UndoHelper::recordBeforeState()
             info.oldTrackIndex = i;
             info.oldClipIndex = j;
             info.isBlank = playlist.is_blank(j);
+            if (clipInfo.cut && clipInfo.cut->property_exists(kShotcutGroupProperty)) {
+                info.group = clipInfo.cut->get_int(kShotcutGroupProperty);
+            }
         }
     }
 }
@@ -69,7 +75,7 @@ void UndoHelper::recordBeforeState()
 void UndoHelper::recordAfterState()
 {
 #ifdef UNDOHELPER_DEBUG
-    debugPrintState();
+    debugPrintState("After state");
 #endif
     QList<QUuid> clipsRemoved = m_state.keys();
     m_clipsAdded.clear();
@@ -80,7 +86,10 @@ void UndoHelper::recordAfterState()
 
         for (int j = 0; j < playlist.count(); ++j) {
             QScopedPointer<Mlt::Producer> clip(playlist.get_clip(j));
-            QUuid uid = MLT.ensureHasUuid(*clip);
+            QUuid uid = MLT.ensureHasUuid(clip->parent());
+            if (clip->is_blank()) {
+                uid = MLT.ensureHasUuid(*clip);
+            }
 
             /* Clips not previously in m_state are new */
             if (!m_state.contains(uid)) {
@@ -140,14 +149,17 @@ void UndoHelper::recordAfterState()
 void UndoHelper::undoChanges()
 {
 #ifdef UNDOHELPER_DEBUG
-    debugPrintState();
+    debugPrintState("Before undo");
 #endif
     if (m_hints & RestoreTracks) {
         restoreAffectedTracks();
         emit m_model.modified();
+#ifdef UNDOHELPER_DEBUG
+        debugPrintState("After undo");
+#endif
         return;
     }
-    int indexAdjustment = 0;
+    QMap<int, int> indexAdjustment;
 
     /* We're walking through the list in the order of uids, which is the order in which the
      * clips were laid out originally. As we go through the clips we make sure the clips behind
@@ -157,12 +169,12 @@ void UndoHelper::undoChanges()
         UNDOLOG << "Handling uid" << uid << "on track" << info.oldTrackIndex << "index" <<
                 info.oldClipIndex;
 
-        int mltIndex = m_model.trackList()[info.oldTrackIndex].mlt_index;
-        QScopedPointer<Mlt::Producer> trackProducer(m_model.tractor()->track(mltIndex));
+        int trackIndex = m_model.trackList()[info.oldTrackIndex].mlt_index;
+        QScopedPointer<Mlt::Producer> trackProducer(m_model.tractor()->track(trackIndex));
         Mlt::Playlist playlist(*trackProducer);
 
         /* This is the index in the track we're currently restoring */
-        int currentIndex = qMin(info.oldClipIndex + indexAdjustment, playlist.count() - 1);
+        int currentIndex = qMin(info.oldClipIndex + indexAdjustment[trackIndex], playlist.count() - 1);
 
         /* Clips that were moved are simply searched for using the uid, and moved in place. We
          * do not use the indices directly because they become invalid once the playlist is
@@ -172,7 +184,7 @@ void UndoHelper::undoChanges()
             int clipCurrentlyAt = -1;
             for (int i = 0; i < playlist.count(); ++i) {
                 QScopedPointer<Mlt::Producer> clip(playlist.get_clip(i));
-                if (MLT.uuid(*clip) == uid) {
+                if (MLT.uuid(clip->parent()) == uid || MLT.uuid(*clip) == uid) {
                     clipCurrentlyAt = i;
                     break;
                 }
@@ -199,7 +211,7 @@ void UndoHelper::undoChanges()
                 playlist.insert_blank(currentIndex, info.frame_out - info.frame_in);
                 UNDOLOG << "inserting isBlank at " << currentIndex;
             } else {
-                UNDOLOG << "inserting clip at " << currentIndex;
+                UNDOLOG << "inserting clip at " << currentIndex << uid;
                 Q_ASSERT(!(m_hints & SkipXML) && "Cannot restore clip without stored XML");
                 Q_ASSERT(!info.xml.isEmpty());
                 Mlt::Producer restoredClip(MLT.profile(), "xml-string", info.xml.toUtf8().constData());
@@ -215,9 +227,16 @@ void UndoHelper::undoChanges()
             QScopedPointer<Mlt::Producer> clip(playlist.get_clip(currentIndex));
             Q_ASSERT(currentIndex < playlist.count());
             Q_ASSERT(!clip.isNull());
-            MLT.setUuid(*clip, uid);
+            if (info.isBlank) {
+                MLT.setUuid(*clip, uid);
+            } else {
+                MLT.setUuid(clip->parent(), uid);
+            }
+            if (info.group >= 0) {
+                clip->set(kShotcutGroupProperty, info.group);
+            }
             AudioLevelsTask::start(clip->parent(), &m_model, modelIndex);
-            ++indexAdjustment;
+            indexAdjustment[trackIndex]++;
         }
 
         /* Only in/out points handled so far */
@@ -258,7 +277,10 @@ void UndoHelper::undoChanges()
         Mlt::Playlist playlist(*trackProducer);
         for (int i = playlist.count() - 1; i >= 0; --i) {
             QScopedPointer<Mlt::Producer> clip(playlist.get_clip(i));
-            QUuid uid = MLT.uuid(*clip);
+            QUuid uid = MLT.uuid(clip->parent());
+            if (clip->is_blank()) {
+                uid = MLT.uuid(*clip);
+            }
             if (m_clipsAdded.removeOne(uid)) {
                 UNDOLOG << "Removing clip at" << i;
                 m_model.beginRemoveRows(m_model.index(trackIndex), i, i);
@@ -277,7 +299,7 @@ void UndoHelper::undoChanges()
 
     emit m_model.modified();
 #ifdef UNDOHELPER_DEBUG
-    debugPrintState();
+    debugPrintState("After undo");
 #endif
 }
 
@@ -286,9 +308,9 @@ void UndoHelper::setHints(OptimizationHints hints)
     m_hints = hints;
 }
 
-void UndoHelper::debugPrintState()
+void UndoHelper::debugPrintState(const QString &title)
 {
-    qDebug("timeline state: {");
+    LOG_DEBUG() << "timeline state:" << title << "{";
     for (int i = 0; i < m_model.trackList().count(); ++i) {
         int mltIndex = m_model.trackList()[i].mlt_index;
         QString trackStr = QString("   track %1 (mlt-idx %2):").arg(i).arg(mltIndex);
@@ -296,15 +318,18 @@ void UndoHelper::debugPrintState()
         Mlt::Playlist playlist(*trackProducer);
 
         for (int j = 0; j < playlist.count(); ++j) {
-            QScopedPointer<Mlt::Producer> clip(playlist.get_clip(j));
             Mlt::ClipInfo info;
             playlist.clip_info(j, &info);
+            QUuid uid = MLT.uuid(*info.producer);
+            if (info.producer->is_blank() && info.cut) {
+                uid = MLT.uuid(*info.cut);
+            }
             trackStr += QString(" [ %5 %1 -> %2 (%3 frames) %4]").arg(info.frame_in).arg(info.frame_out).arg(
-                            info.frame_count).arg(clip->is_blank() ? "blank " : "").arg(MLT.uuid(*clip).toString());
+                            info.frame_count).arg(info.cut->is_blank() ? "blank " : "clip").arg(uid.toString());
         }
         LOG_DEBUG() << qPrintable(trackStr);
     }
-    qDebug("}");
+    LOG_DEBUG() << "}";
 }
 
 void UndoHelper::restoreAffectedTracks()
@@ -313,9 +338,9 @@ void UndoHelper::restoreAffectedTracks()
     for (const auto &trackIndex : qAsConst(m_affectedTracks)) {
         if (trackIndex >= 0 && trackIndex < m_model.trackList().size()) {
             auto mlt_index = m_model.trackList().at(trackIndex).mlt_index;
-            Mlt::Producer producer = m_model.tractor()->multitrack()->track(mlt_index);
-            if (producer.is_valid()) {
-                Mlt::Playlist playlist(producer);
+            QScopedPointer<Mlt::Producer> producer(m_model.tractor()->track(mlt_index));
+            if (producer->is_valid()) {
+                Mlt::Playlist playlist(*producer.data());
                 m_model.beginRemoveRows(m_model.index(trackIndex), 0, playlist.count() - 1);
                 UNDOLOG << "clearing track" << trackIndex;
                 playlist.clear();
@@ -338,7 +363,7 @@ void UndoHelper::restoreAffectedTracks()
             m_model.beginInsertRows(modelIndex.parent(), currentIndex, currentIndex);
             if (info.isBlank) {
                 playlist.blank(info.frame_out - info.frame_in);
-                UNDOLOG << "appending blank at" << currentIndex;
+                UNDOLOG << "appending blank at" << currentIndex << info.frame_out << info.frame_in;
             } else {
                 UNDOLOG << "appending clip at" << currentIndex;
                 Q_ASSERT(!(m_hints & SkipXML) && "Cannot restore clip without stored XML");
@@ -348,23 +373,30 @@ void UndoHelper::restoreAffectedTracks()
                     restoredClip.set("mlt_type", "mlt_producer");
                 }
                 playlist.append(restoredClip, info.frame_in, info.frame_out);
-
+                if (info.group >= 0) {
+                    QScopedPointer<Mlt::Producer> clip(playlist.get_clip(currentIndex));
+                    clip->set(kShotcutGroupProperty, info.group);
+                }
             }
             m_model.endInsertRows();
 
             QScopedPointer<Mlt::Producer> clip(playlist.get_clip(currentIndex));
             Q_ASSERT(currentIndex < playlist.count());
             Q_ASSERT(!clip.isNull());
-            MLT.setUuid(*clip, uid);
+            if (info.isBlank) {
+                MLT.setUuid(*clip, uid);
+            } else {
+                MLT.setUuid(clip->parent(), uid);
+            }
             AudioLevelsTask::start(clip->parent(), &m_model, modelIndex);
         }
     }
     for (const auto &trackIndex : qAsConst(m_affectedTracks)) {
         if (trackIndex >= 0 && trackIndex < m_model.trackList().size()) {
             auto mlt_index = m_model.trackList().at(trackIndex).mlt_index;
-            Mlt::Producer producer = m_model.tractor()->multitrack()->track(mlt_index);
-            if (producer.is_valid()) {
-                Mlt::Playlist playlist(producer);
+            QScopedPointer<Mlt::Producer> producer(m_model.tractor()->track(mlt_index));
+            if (producer->is_valid()) {
+                Mlt::Playlist playlist(*producer.data());
                 for (auto currentIndex = 0; currentIndex < playlist.count(); currentIndex++) {
                     Mlt::Producer clip = playlist.get_clip(currentIndex);
                     fixTransitions(playlist, currentIndex, clip);
@@ -388,13 +420,13 @@ void UndoHelper::fixTransitions(Mlt::Playlist playlist, int clipIndex, Mlt::Prod
         if (producer.is_valid() && producer.parent().get(kShotcutTransitionProperty)) {
             Mlt::Tractor transition(producer.parent());
             if (transition.is_valid()) {
-                Mlt::Producer transitionClip(transition.track(transitionIndex));
-                if (transitionClip.is_valid()
-                        && transitionClip.parent().get_service() != clip.parent().get_service()) {
+                QScopedPointer<Mlt::Producer> transitionClip(transition.track(transitionIndex));
+                if (transitionClip->is_valid()
+                        && transitionClip->parent().get_service() != clip.parent().get_service()) {
                     UNDOLOG << "Fixing transition at clip index" << currentIndex << "transition index" <<
                             transitionIndex;
-                    transitionClip = clip.cut(transitionClip.get_in(), transitionClip.get_out());
-                    transition.set_track(transitionClip, transitionIndex);
+                    transitionClip.reset(clip.cut(transitionClip->get_in(), transitionClip->get_out()));
+                    transition.set_track(*transitionClip.data(), transitionIndex);
                 }
             }
         }
