@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2022 Meltytech, LLC
+ * Copyright (c) 2014-2023 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,11 +27,11 @@
 #include "qmltypes/qmlmetadata.h"
 #include "qmltypes/qmlutilities.h"
 #include "qmltypes/qmlfilter.h"
+#include "qmltypes/qmlapplication.h"
 
 #include <MltLink.h>
 
 FilterController::FilterController(QObject *parent) : QObject(parent),
-    m_mltService(0),
     m_metadataModel(this),
     m_attachedModel(this),
     m_currentFilterIndex(QmlFilter::NoCurrentFilter)
@@ -40,6 +40,8 @@ FilterController::FilterController(QObject *parent) : QObject(parent),
     connect(&m_attachedModel, SIGNAL(changed()), this, SLOT(handleAttachedModelChange()));
     connect(&m_attachedModel, SIGNAL(modelAboutToBeReset()), this,
             SLOT(handleAttachedModelAboutToReset()));
+    connect(&m_attachedModel, SIGNAL(rowsAboutToBeRemoved(const QModelIndex &, int, int)), this,
+            SLOT(handleAttachedRowsAboutToBeRemoved(const QModelIndex &, int, int)));
     connect(&m_attachedModel, SIGNAL(rowsRemoved(const QModelIndex &, int, int)), this,
             SLOT(handleAttachedRowsRemoved(const QModelIndex &, int, int)));
     connect(&m_attachedModel, SIGNAL(rowsInserted(const QModelIndex &, int, int)), this,
@@ -108,20 +110,14 @@ void FilterController::loadFilterMetadata()
     };
 }
 
-QmlMetadata *FilterController::metadataForService(Mlt::Service *service)
+QmlMetadata *FilterController::metadata(const QString &id)
 {
     QmlMetadata *meta = 0;
     int rowCount = m_metadataModel.rowCount();
-    QString uniqueId = service->get(kShotcutFilterProperty);
-
-    // Fallback to mlt_service for legacy filters
-    if (uniqueId.isEmpty()) {
-        uniqueId = service->get("mlt_service");
-    }
 
     for (int i = 0; i < rowCount; i++) {
         QmlMetadata *tmpMeta = m_metadataModel.get(i);
-        if (tmpMeta->uniqueId() == uniqueId) {
+        if (tmpMeta->uniqueId() == id) {
             meta = tmpMeta;
             break;
         }
@@ -130,9 +126,77 @@ QmlMetadata *FilterController::metadataForService(Mlt::Service *service)
     return meta;
 }
 
+QmlMetadata *FilterController::metadataForService(Mlt::Service *service)
+{
+    QmlMetadata *meta = nullptr;
+    int rowCount = m_metadataModel.rowCount();
+    QString uniqueId = service->get(kShotcutFilterProperty);
+
+    // Fallback to mlt_service for legacy filters
+    if (uniqueId.isEmpty()) {
+        uniqueId = service->get("mlt_service");
+    }
+
+    return metadata(uniqueId);
+}
+
+bool FilterController::isOutputTrackSelected() const
+{
+    return m_attachedModel.producer() && m_attachedModel.producer()->is_valid()
+           && mlt_service_tractor_type == m_attachedModel.producer()->type()
+           && !m_attachedModel.producer()->get(kShotcutTransitionProperty)
+           && m_attachedModel.rowCount() == 0;
+}
+
+void FilterController::loadFilterSets()
+{
+    QStringList sets;
+    auto dir = QmlApplication::dataDir();
+    if (dir.cd("shotcut") && dir.cd("filter-sets")) {
+        QStringList entries = dir.entryList(QDir::Files | QDir::Readable);
+        for (const auto &s : entries) {
+            auto meta = new QmlMetadata;
+            meta->setType(QmlMetadata::FilterSet);
+            if (s == QUrl::toPercentEncoding(QUrl::fromPercentEncoding(s.toUtf8())))
+                meta->setName(QUrl::fromPercentEncoding(s.toUtf8()));
+            else
+                meta->setName(s);
+            meta->set_mlt_service("stock");
+            meta->loadSettings();
+            addMetadata(meta);
+        }
+    }
+    dir = Settings.appDataLocation();
+    if (dir.cd("filter-sets")) {
+        QStringList entries = dir.entryList(QDir::Files | QDir::Readable);
+        for (const auto &s : entries) {
+            auto meta = new QmlMetadata;
+            meta->setType(QmlMetadata::FilterSet);
+            if (s == QUrl::toPercentEncoding(QUrl::fromPercentEncoding(s.toUtf8())))
+                meta->setName(QUrl::fromPercentEncoding(s.toUtf8()));
+            else
+                meta->setName(s);
+            meta->loadSettings();
+            addMetadata(meta);
+        }
+    }
+}
+
+void FilterController::onUndoOrRedo(Mlt::Service &service)
+{
+    MLT.refreshConsumer();
+    if (m_currentFilter && m_mltService.is_valid()
+            && service.get_service() == m_mltService.get_service()) {
+        emit undoOrRedo();
+        QMetaObject::invokeMethod(this, "setCurrentFilter", Qt::QueuedConnection, Q_ARG(int,
+                                                                                        m_currentFilterIndex));
+    }
+}
+
 void FilterController::timerEvent(QTimerEvent *event)
 {
     loadFilterMetadata();
+    loadFilterSets();
     killTimer(event->timerId());
 }
 
@@ -150,12 +214,13 @@ void FilterController::setProducer(Mlt::Producer *producer)
 {
     m_attachedModel.setProducer(producer);
     if (producer && producer->is_valid()) {
-        m_metadataModel.setIsClipProducer(!MLT.isTrackProducer(*producer));
-        m_metadataModel.setIsChainProducer(producer->type() == mlt_service_chain_type);
+        m_metadataModel.updateFilterMask(!MLT.isTrackProducer(*producer),
+                                         producer->type() == mlt_service_chain_type,
+                                         producer->type() == mlt_service_playlist_type);
     }
 }
 
-void FilterController::setCurrentFilter(int attachedIndex, bool isNew)
+void FilterController::setCurrentFilter(int attachedIndex)
 {
     if (attachedIndex == m_currentFilterIndex) {
         return;
@@ -164,9 +229,9 @@ void FilterController::setCurrentFilter(int attachedIndex, bool isNew)
 
     // VUIs may instruct MLT filters to not render if they are doing the rendering
     // theirself, for example, Text: Rich. Component.onDestruction is not firing.
-    if (m_mltService) {
-        if (m_mltService->get_int("_hide")) {
-            m_mltService->clear("_hide");
+    if (m_mltService.is_valid()) {
+        if (m_mltService.get_int("_hide")) {
+            m_mltService.clear("_hide");
             MLT.refreshConsumer();
         }
     }
@@ -176,14 +241,18 @@ void FilterController::setCurrentFilter(int attachedIndex, bool isNew)
     if (meta) {
         emit currentFilterChanged(nullptr, nullptr, QmlFilter::NoCurrentFilter);
         m_mltService = m_attachedModel.getService(m_currentFilterIndex);
-        if (!m_mltService) return;
-        filter = new QmlFilter(*m_mltService, meta);
-        filter->setIsNew(isNew);
+        if (!m_mltService.is_valid()) return;
+        filter = new QmlFilter(m_mltService, meta);
+        filter->setIsNew(m_mltService.get_int(kNewFilterProperty));
+        m_mltService.clear(kNewFilterProperty);
         connect(filter, SIGNAL(changed(QString)), SLOT(onQmlFilterChanged(const QString &)));
     }
 
     emit currentFilterChanged(filter, meta, m_currentFilterIndex);
     m_currentFilter.reset(filter);
+    if (filter && !m_attachedModel.isSourceClip()) {
+        filter->startUndoTracking(this, m_currentFilterIndex);
+    }
 }
 
 void FilterController::onFadeInChanged()
@@ -233,13 +302,13 @@ void FilterController::handleAttachedModelAboutToReset()
 void FilterController::handleAttachedRowsRemoved(const QModelIndex &, int first, int)
 {
     m_currentFilterIndex = QmlFilter::DeselectCurrentFilter; // Force update
-    setCurrentFilter(qBound(0, first, m_attachedModel.rowCount() - 1));
+    setCurrentFilter(qBound(0, first, qMax(m_attachedModel.rowCount() - 1, 0)));
 }
 
 void FilterController::handleAttachedRowsInserted(const QModelIndex &, int first, int)
 {
     m_currentFilterIndex = QmlFilter::DeselectCurrentFilter; // Force update
-    setCurrentFilter(qBound(0, first, m_attachedModel.rowCount() - 1), true);
+    setCurrentFilter(qBound(0, first, qMax(m_attachedModel.rowCount() - 1, 0)));
 }
 
 void FilterController::handleAttachDuplicateFailed(int index)
@@ -255,7 +324,7 @@ void FilterController::onQmlFilterChanged(const QString &name)
         QModelIndex index = m_attachedModel.index(m_currentFilterIndex);
         emit m_attachedModel.dataChanged(index, index, QVector<int>() << Qt::CheckStateRole);
     }
-    emit filterChanged(m_mltService);
+    emit filterChanged(&m_mltService);
 }
 
 void FilterController::removeCurrent()
@@ -273,3 +342,10 @@ void FilterController::addMetadata(QmlMetadata *meta)
 {
     m_metadataModel.add(meta);
 }
+
+void FilterController::handleAttachedRowsAboutToBeRemoved(const QModelIndex &parent, int first,
+                                                          int last)
+{
+    auto filter = m_attachedModel.getService(first);
+    m_motionTrackerModel.remove(m_motionTrackerModel.keyForFilter(filter));
+}
