@@ -29,18 +29,19 @@ class EditMarkerDialog : public QDialog
     Q_OBJECT
 
 public:
-    explicit EditMarkerDialog(QWidget *parent, const QString& text, const QColor& color, int start, int end, int maxEnd);
+    explicit EditMarkerDialog(QWidget *parent, const QString &text, const QColor &color, int start,
+                              int end, int maxEnd);
     QString getText();
     QColor getColor();
     int getStart();
     int getEnd();
 
 private slots:
-    void clicked(QAbstractButton* button);
+    void clicked(QAbstractButton *button);
 
 private:
-    EditMarkerWidget* m_sWidget;
-    QDialogButtonBox* m_buttonBox;
+    EditMarkerWidget *m_sWidget;
+    QDialogButtonBox *m_buttonBox;
 };
 
 #endif // EDITMARKERDIALOG_H
