@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2019 Meltytech, LLC
+ * Copyright (c) 2012-2024 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,12 +21,20 @@
 #include "util.h"
 
 #include <QFileDialog>
+#include <QPushButton>
+#include <QClipboard>
+#include <QScrollBar>
 
-TextViewerDialog::TextViewerDialog(QWidget *parent) :
+TextViewerDialog::TextViewerDialog(QWidget *parent, bool forMltXml) :
     QDialog(parent),
-    ui(new Ui::TextViewerDialog)
+    ui(new Ui::TextViewerDialog),
+    m_forMltXml(forMltXml)
 {
     ui->setupUi(this);
+    auto button = ui->buttonBox->addButton(tr("Copy"), QDialogButtonBox::ActionRole);
+    connect(button, &QAbstractButton::clicked, this, [&]() {
+        QGuiApplication::clipboard()->setText(ui->plainTextEdit->toPlainText());
+    });
 }
 
 TextViewerDialog::~TextViewerDialog()
@@ -34,9 +42,18 @@ TextViewerDialog::~TextViewerDialog()
     delete ui;
 }
 
-void TextViewerDialog::setText(const QString &s)
+void TextViewerDialog::setText(const QString &s, bool scroll)
 {
-    ui->plainTextEdit->setPlainText(s);
+    if (s != ui->plainTextEdit->toPlainText()) {
+        ui->plainTextEdit->setPlainText(s);
+        if (scroll)
+            ui->plainTextEdit->verticalScrollBar()->setValue(ui->plainTextEdit->verticalScrollBar()->maximum());
+    }
+}
+
+QDialogButtonBox *TextViewerDialog::buttonBox() const
+{
+    return ui->buttonBox;
 }
 
 void TextViewerDialog::on_buttonBox_accepted()
@@ -44,9 +61,19 @@ void TextViewerDialog::on_buttonBox_accepted()
     QString path = Settings.savePath();
     QString caption = tr("Save Text");
     QString nameFilter = tr("Text Documents (*.txt);;All Files (*)");
+    if (m_forMltXml) {
+        nameFilter = tr("MLT XML (*.mlt);;All Files (*)");
+    }
     QString filename = QFileDialog::getSaveFileName(this, caption, path, nameFilter,
                                                     nullptr, Util::getFileDialogOptions());
     if (!filename.isEmpty()) {
+        QFileInfo fi(filename);
+        if (fi.suffix().isEmpty()) {
+            if (m_forMltXml)
+                filename += ".mlt";
+            else
+                filename += ".txt";
+        }
         if (Util::warnIfNotWritable(filename, this, caption))
             return;
         QFile f(filename);
