@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2021 Meltytech, LLC
+ * Copyright (c) 2012-2024 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@
 #include "dialogs/durationdialog.h"
 #include "dialogs/filedatedialog.h"
 #include "dialogs/longuitask.h"
+#include "dialogs/resourcedialog.h"
 #include "dialogs/slideshowgeneratordialog.h"
 #include "mainwindow.h"
 #include "settings.h"
@@ -46,6 +47,7 @@
 #include <QDir>
 #include <QGuiApplication>
 #include <QClipboard>
+#include <QActionGroup>
 
 static const int kInOutChangedTimeoutMs = 100;
 
@@ -303,22 +305,18 @@ void PlaylistDock::setupActions()
     QAction *action;
 
     action = new QAction(tr("Append"), this);
-    action->setShortcut(QKeySequence(Qt::SHIFT + Qt::Key_A));
+    action->setShortcut(QKeySequence(Qt::SHIFT | Qt::Key_A));
     action->setToolTip(tr("Add the Source to the playlist"));
     icon = QIcon::fromTheme("list-add",
                             QIcon(":/icons/oxygen/32x32/actions/list-add.png"));
     action->setIcon(icon);
-    action->setEnabled(false);
     connect(action, &QAction::triggered, this, &PlaylistDock::onAppendCutActionTriggered);
-    connect(this, &PlaylistDock::producerOpened, action, [ = ]() {
-        action->setEnabled(!MLT.isMultitrack() && !MLT.isPlaylist());
-    });
     Actions.add("playlistAppendCutAction", action);
 
     action = new QAction(tr("Remove"), this);
     QList<QKeySequence> removeShortcuts;
-    removeShortcuts << QKeySequence(Qt::SHIFT + Qt::Key_X);
-    removeShortcuts << QKeySequence(Qt::SHIFT + Qt::Key_Z);
+    removeShortcuts << QKeySequence(Qt::SHIFT | Qt::Key_X);
+    removeShortcuts << QKeySequence(Qt::SHIFT | Qt::Key_Z);
     action->setShortcuts(removeShortcuts);
     action->setToolTip(tr("Remove cut"));
     icon = QIcon::fromTheme("list-remove",
@@ -340,7 +338,7 @@ void PlaylistDock::setupActions()
     Actions.add("playlistAddFilesAction", action);
 
     action = new QAction(tr("Update"), this);
-    action->setShortcut(QKeySequence(Qt::SHIFT + Qt::Key_B));
+    action->setShortcut(QKeySequence(Qt::SHIFT | Qt::Key_B));
     icon = QIcon::fromTheme("dialog-ok",
                             QIcon(":/icons/oxygen/32x32/actions/dialog-ok.png"));
     action->setIcon(icon);
@@ -392,7 +390,7 @@ void PlaylistDock::setupActions()
 
     action = new QAction(tr("Open"), this);
     action->setToolTip(tr("Open the clip in the Source player"));
-    action->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_Return));
+    action->setShortcut(QKeySequence(Qt::CTRL | Qt::Key_Return));
     action->setEnabled(false);
     connect(action, &QAction::triggered, this, &PlaylistDock::onOpenActionTriggered);
     connect(this, &PlaylistDock::selectionChanged, action, [ = ]() {
@@ -402,17 +400,13 @@ void PlaylistDock::setupActions()
 
     action = new QAction(tr("GoTo"), this);
     action->setToolTip(tr("Go to the start of this clip in the Project player"));
-    action->setShortcut(QKeySequence(Qt::SHIFT + Qt::Key_Return));
-    action->setEnabled(false);
+    action->setShortcut(QKeySequence(Qt::SHIFT | Qt::Key_Return));
     connect(action, &QAction::triggered, this, &PlaylistDock::onGotoActionTriggered);
-    connect(this, &PlaylistDock::producerOpened, action, [ = ]() {
-        action->setEnabled(!MLT.isMultitrack() && !MLT.isPlaylist());
-    });
     Actions.add("playlistGoToAction", action);
 
     action = new QAction(tr("Copy"), this);
     action->setToolTip(tr("Open a copy of the clip in the Source player"));
-    action->setShortcut(QKeySequence(Qt::SHIFT + Qt::Key_C));
+    action->setShortcut(QKeySequence(Qt::SHIFT | Qt::Key_C));
     action->setEnabled(false);
     connect(action, &QAction::triggered, this, &PlaylistDock::onCopyActionTriggered);
     connect(this, &PlaylistDock::selectionChanged, action, [ = ]() {
@@ -422,12 +416,8 @@ void PlaylistDock::setupActions()
 
     action = new QAction(tr("Insert"), this);
     action->setToolTip(tr("Insert"));
-    action->setShortcut(QKeySequence(Qt::SHIFT + Qt::Key_V));
-    action->setEnabled(false);
+    action->setShortcut(QKeySequence(Qt::SHIFT | Qt::Key_V));
     connect(action, &QAction::triggered, this, &PlaylistDock::onInsertCutActionTriggered);
-    connect(this, &PlaylistDock::producerOpened, action, [ = ]() {
-        action->setEnabled(MLT.isClip() || MLT.savedProducer());
-    });
     Actions.add("playlistInsertCutAction", action);
 
     action = new QAction(tr("Update Thumbnails"), this);
@@ -449,21 +439,17 @@ void PlaylistDock::setupActions()
     action = new QAction(tr("Remove All"), this);
     action->setToolTip(tr("Remove all items from the playlist"));
     connect(action, &QAction::triggered, this, &PlaylistDock::onRemoveAllActionTriggered);
-    connect(this, &PlaylistDock::selectionChanged, action, [ = ]() {
-        action->setEnabled(m_model.rowCount() > 0);
-    });
+    action->setEnabled(m_model.rowCount() > 0);
     Actions.add("playlistRemoveAllAction", action);
 
     action = new QAction(tr("Select All"), this);
-    action->setShortcut(QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_A));
+    action->setShortcut(QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_A));
     connect(action, &QAction::triggered, this, &PlaylistDock::onSelectAllActionTriggered);
-    connect(this, &PlaylistDock::selectionChanged, action, [ = ]() {
-        action->setEnabled(m_model.rowCount() > 0);
-    });
+    action->setEnabled(m_model.rowCount() > 0);
     Actions.add("playlistSelectAllAction", action);
 
     action = new QAction(tr("Select None"), this);
-    action->setShortcut(QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_D));
+    action->setShortcut(QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_D));
     connect(action, &QAction::triggered, m_selectionModel, &QItemSelectionModel::clearSelection);
     connect(this, &PlaylistDock::selectionChanged, action, [ = ]() {
         action->setEnabled(m_selectionModel->selection().size() > 0);
@@ -471,7 +457,7 @@ void PlaylistDock::setupActions()
     Actions.add("playlistSelectNoneAction", action);
 
     action = new QAction(tr("Move Up"), this);
-    action->setShortcut(QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_Up));
+    action->setShortcut(QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_Up));
     connect(action, &QAction::triggered, m_selectionModel, [ = ]() {
         raise();
         moveClipUp();
@@ -483,7 +469,7 @@ void PlaylistDock::setupActions()
     Actions.add("playlistMoveUpAction", action);
 
     action = new QAction(tr("Move Down"), this);
-    action->setShortcut(QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_Down));
+    action->setShortcut(QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_Down));
     connect(action, &QAction::triggered, m_selectionModel, [ = ]() {
         raise();
         moveClipDown();
@@ -608,7 +594,7 @@ void PlaylistDock::setupActions()
     Actions.add("playlistPlayAfterOpenAction", action);
 
     action = new QAction(tr("Open Previous"), this);
-    action->setShortcut(QKeySequence(Qt::ALT + Qt::Key_Up));
+    action->setShortcut(QKeySequence(Qt::ALT | Qt::Key_Up));
     action->setEnabled(false);
     connect(action, &QAction::triggered, this, [ = ]() {
         raise();
@@ -621,7 +607,7 @@ void PlaylistDock::setupActions()
     Actions.add("playlistOpenPreviousAction", action);
 
     action = new QAction(tr("Open Next"), this);
-    action->setShortcut(QKeySequence(Qt::ALT + Qt::Key_Down));
+    action->setShortcut(QKeySequence(Qt::ALT | Qt::Key_Down));
     action->setEnabled(false);
     connect(action, &QAction::triggered, this, [ = ]() {
         raise();
@@ -780,6 +766,27 @@ void PlaylistDock::replaceClipsWithHash(const QString &hash, Mlt::Producer &prod
     }
 }
 
+void PlaylistDock::getSelectionRange(int *start, int *end)
+{
+    Mlt::Playlist *playlist = m_model.playlist();
+    if (!playlist || !m_view->selectionModel()
+            || !m_view->selectionModel()->selectedIndexes().size() ) {
+        *start = -1;
+        *end = -1;
+        return;
+    }
+    // Find the earliest start and the latest end in the selection
+    *start = std::numeric_limits<int>::max();
+    *end = -1;
+    foreach (auto index, m_view->selectionModel()->selectedIndexes()) {
+        int row = index.row();
+        int clipStart = playlist->clip_start(row);
+        int clipEnd = clipStart + playlist->clip_length(row);
+        *start = qMin(*start, clipStart);
+        *end = qMax(*end, clipEnd);
+    }
+}
+
 void PlaylistDock::incrementIndex()
 {
     QModelIndex index = m_view->currentIndex();
@@ -1066,6 +1073,9 @@ void PlaylistDock::onPlaylistCreated()
 void PlaylistDock::onPlaylistLoaded()
 {
     onPlaylistCreated();
+    bool nonEmptyModel = m_model.rowCount() > 0;
+    Actions["playlistRemoveAllAction"]->setEnabled(nonEmptyModel);
+    Actions["playlistSelectAllAction"]->setEnabled(nonEmptyModel);
 }
 
 void PlaylistDock::onPlaylistModified()
@@ -1074,23 +1084,30 @@ void PlaylistDock::onPlaylistModified()
         ui->tableView->resizeColumnsToContents();
         m_blockResizeColumnsToContents = true;
     }
+    bool nonEmptyModel = m_model.rowCount() > 0;
+    Actions["playlistRemoveAllAction"]->setEnabled(nonEmptyModel);
+    Actions["playlistSelectAllAction"]->setEnabled(nonEmptyModel);
 }
 
 void PlaylistDock::onPlaylistCleared()
 {
     emit enableUpdate(false);
     m_blockResizeColumnsToContents = false;
+    bool nonEmptyModel = m_model.rowCount() > 0;
+    Actions["playlistRemoveAllAction"]->setEnabled(nonEmptyModel);
+    Actions["playlistSelectAllAction"]->setEnabled(nonEmptyModel);
 }
 
 void PlaylistDock::onDropped(const QMimeData *data, int row)
 {
     bool resetIndex = true;
     if (data && data->hasUrls()) {
+        ResourceDialog dialog(this);
         LongUiTask longTask(tr("Add Files"));
         int insertNextAt = row;
         bool first = true;
         QStringList fileNames = Util::sortedFileList(Util::expandDirectories(data->urls()));
-        auto i = 0, count = fileNames.size();
+        qsizetype i = 0, count = fileNames.size();
         for (auto &path : fileNames) {
             if (MAIN.isSourceClipMyProject(path)) continue;
             longTask.reportProgress(Util::baseName(path), i++, count);
@@ -1100,7 +1117,17 @@ void PlaylistDock::onDropped(const QMimeData *data, int row)
             }
             Mlt::Producer p;
             if (path.endsWith(".mlt") || path.endsWith(".xml")) {
-                p = Mlt::Producer(MLT.profile(), "xml", path.toUtf8().constData());
+                if (Settings.playerGPU() && MLT.profile().is_explicit()) {
+                    Mlt::Profile testProfile;
+                    Mlt::Producer producer(testProfile, path.toUtf8().constData());
+                    if (testProfile.width() != MLT.profile().width()
+                            || testProfile.height() != MLT.profile().height()
+                            || Util::isFpsDifferent(MLT.profile().fps(), testProfile.fps())) {
+                        emit showStatusMessage(tr("Failed to open ").append(path));
+                        continue;
+                    }
+                }
+                p = Mlt::Producer(MLT.profile(), path.toUtf8().constData());
                 if (p.is_valid()) {
                     // Convert MLT XML to a virtual clip.
                     p.set(kShotcutVirtualClip, 1);
@@ -1115,7 +1142,10 @@ void PlaylistDock::onDropped(const QMimeData *data, int row)
                 if (first) {
                     first = false;
                     if (!MLT.producer() || !MLT.producer()->is_valid()) {
-                        MAIN.open(path, nullptr, false);
+                        Mlt::Properties properties;
+                        if (count > 1)
+                            properties.set(kShotcutSkipConvertProperty, 1);
+                        MAIN.open(path, &properties, false);
                         if (MLT.producer() && MLT.producer()->is_valid()) {
                             producer = MLT.producer();
                             first = true;
@@ -1123,6 +1153,8 @@ void PlaylistDock::onDropped(const QMimeData *data, int row)
                     }
                 }
                 producer = MLT.setupNewProducer(producer);
+                if (count > 1)
+                    producer->set(kShotcutSkipConvertProperty, 1);
                 if (!MLT.isLiveProducer(producer) || producer->get_int(kShotcutVirtualClip)) {
                     ProxyManager::generateIfNotExists(*producer);
                     if (row == -1)
@@ -1131,10 +1163,10 @@ void PlaylistDock::onDropped(const QMimeData *data, int row)
                         MAIN.undoStack()->push(new Playlist::InsertCommand(m_model, MLT.XML(producer), insertNextAt++));
                 } else {
                     LongUiTask::cancel();
-                    DurationDialog dialog(this);
-                    dialog.setDuration(MLT.profile().fps() * 5);
-                    if (dialog.exec() == QDialog::Accepted) {
-                        producer->set_in_and_out(0, dialog.duration() - 1);
+                    DurationDialog durationDialog(this);
+                    durationDialog.setDuration(MLT.profile().fps() * 5);
+                    if (durationDialog.exec() == QDialog::Accepted) {
+                        producer->set_in_and_out(0, durationDialog.duration() - 1);
                         if (row == -1)
                             MAIN.undoStack()->push(new Playlist::AppendCommand(m_model, MLT.XML(producer)));
                         else
@@ -1146,9 +1178,16 @@ void PlaylistDock::onDropped(const QMimeData *data, int row)
                     setIndex(0);
                     resetIndex = false;
                 }
+                dialog.add(producer);
                 delete producer;
             }
         }
+        if (Settings.showConvertClipDialog() && dialog.hasTroubleClips()) {
+            dialog.selectTroubleClips();
+            dialog.setWindowTitle(tr("Dropped Files"));
+            longTask.cancel();
+            dialog.exec();
+        }
     } else if (data && data->hasFormat(Mlt::XmlMimeType)) {
         if (MLT.producer() && MLT.producer()->is_valid()) {
             if (MLT.producer()->type() == mlt_service_playlist_type) {
@@ -1215,6 +1254,7 @@ void PlaylistDock::onAddToTimelineActionTriggered()
 
 void PlaylistDock::onAddToSlideshowActionTriggered()
 {
+    MLT.pause();
     const QModelIndexList &indexes = m_view->selectionModel()->selectedIndexes();
     Mlt::Playlist playlist(MLT.profile());
     foreach (auto index, indexes) {
@@ -1232,8 +1272,8 @@ void PlaylistDock::onAddToSlideshowActionTriggered()
     dialog.setWindowModality(QmlApplication::dialogModality());
     if (dialog.exec() == QDialog::Accepted ) {
         LongUiTask longTask(QObject::tr("Generate Slideshow"));
-        Mlt::Playlist *slideshow = longTask.runAsync<Mlt::Playlist *>(tr("Generating"), &dialog,
-                                                                      &SlideshowGeneratorDialog::getSlideshow);
+        Mlt::Playlist *slideshow = longTask.runAsync<Mlt::Playlist *>(tr("Generating"),
+                                                                      &SlideshowGeneratorDialog::getSlideshow, &dialog);
         if (slideshow) {
             if ( slideshow->count() > 0 ) {
                 emit addAllTimeline(slideshow, /* skipProxy */ true);
