@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2020 Meltytech, LLC
+ * Copyright (c) 2012-2023 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -75,6 +75,10 @@ RecentDock::~RecentDock()
 
 void RecentDock::add(const QString &s)
 {
+    // Block anything big that can cause a performance problem
+    if (s.size() > ShotcutSettings::MaxPath)
+        return;
+
     QString filePath = QDir::fromNativeSeparators(s);
     if (filePath.startsWith(QDir::tempPath())) return;
     QString name = remove(s);
