@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2020 Meltytech, LLC
+ * Copyright (c) 2012-2024 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,8 +18,7 @@
 #include "jobqueue.h"
 #include <QtWidgets>
 #include <Logger.h>
-#include "settings.h"
-#ifdef Q_OS_WIN
+#if defined(Q_OS_WIN) && (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
 #include "windowstools.h"
 #endif
 
@@ -57,11 +56,9 @@ AbstractJob *JobQueue::add(AbstractJob *job)
     QStandardItem *item = new QStandardItem(job->label());
     items << item;
     item = new QStandardItem(tr("pending"));
-#ifdef Q_OS_MAC
     QFont font = QFontDatabase::systemFont(QFontDatabase::FixedFont);
     font.setPointSize(QGuiApplication::font().pointSize());
     item->setFont(font);
-#endif
     item->setToolTip(tr("Estimated Hours:Minutes:Seconds"));
     items << item;
     appendRow(items);
@@ -85,13 +82,24 @@ void JobQueue::onProgressUpdated(QStandardItem *standardItem, int percent)
     if (standardItem) {
         AbstractJob *job = m_jobs.at(standardItem->row());
         if (job) {
-            QString remaining = "--:--:--";
-            if (percent > 2)
-                remaining = job->estimateRemaining(percent).toString();
-            standardItem->setText(QString("%1% (%2)").arg(percent).arg(remaining));
+            QString remaining("--:--:--");
+            QIcon icon(":/icons/oxygen/32x32/actions/run-build.png");
+            if (job->paused()) {
+                icon = QIcon(":/icons/oxygen/32x32/actions/media-playback-pause.png");
+                remaining = tr("paused");
+            } else if (percent > 0) {
+                auto time = job->estimateRemaining(percent);
+                if (percent > 2 && QTime(0, 0).secsTo(time) > 0)
+                    remaining = time.toString();
+                remaining = QString("%1% (%2)").arg(percent).arg(remaining);
+            }
+            standardItem->setText(remaining);
+            standardItem = JOBS.item(standardItem->row(), JobQueue::COLUMN_ICON);
+            if (standardItem)
+                standardItem->setIcon(icon);
         }
     }
-#ifdef Q_OS_WIN
+#if defined(Q_OS_WIN) && (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
     WindowsTaskbarButton::getInstance().setProgress(percent);
 #endif
 }
@@ -124,7 +132,7 @@ void JobQueue::onFinished(AbstractJob *job, bool isSuccess, QString time)
         if (item)
             item->setIcon(icon);
     }
-#ifdef Q_OS_WIN
+#if defined(Q_OS_WIN) && (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
     WindowsTaskbarButton::getInstance().resetProgress();
 #endif
 
@@ -159,12 +167,32 @@ void JobQueue::pause()
     m_paused = true;
 }
 
+void JobQueue::pauseCurrent()
+{
+    for (auto job : m_jobs) {
+        if (job->state() == QProcess::Running) {
+            job->pause();
+            break;
+        }
+    }
+}
+
 void JobQueue::resume()
 {
     m_paused = false;
     startNextJob();
 }
 
+void JobQueue::resumeCurrent()
+{
+    for (auto job : m_jobs) {
+        if (job->state() == QProcess::Running) {
+            job->resume();
+            break;
+        }
+    }
+}
+
 bool JobQueue::isPaused() const
 {
     return m_paused;
