@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2022 Meltytech, LLC
+ * Copyright (c) 2012-2024 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -62,11 +62,14 @@ public:
         return m_totalTime;
     }
     void setPostJobAction(PostJobAction *action);
+    bool paused() const;
 
 public slots:
     void start(const QString &program, const QStringList &arguments);
     virtual void start();
     virtual void stop();
+    void pause();
+    void resume();
 
 signals:
     void progressUpdated(QStandardItem *item, int percent);
@@ -95,6 +98,8 @@ private:
     QElapsedTimer m_totalTime;
     QScopedPointer<PostJobAction> m_postJobAction;
     QThread::Priority m_priority;
+    QAction *m_actionPause;
+    QAction *m_actionResume;
 };
 
 #endif // ABSTRACTJOB_H
