@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011-2022 Meltytech, LLC
+ * Copyright (c) 2011-2023 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,6 +33,14 @@ class QQuickView;
 #define MLT_LC_CATEGORY LC_ALL
 #define MLT_LC_NAME     "LC_ALL"
 
+#if LIBMLT_VERSION_INT >= ((7<<16)+(19<<8))
+#define kAudioIndexProperty "astream"
+#define kVideoIndexProperty "vstream"
+#else
+#define kAudioIndexProperty "audio_index"
+#define kVideoIndexProperty "video_index"
+#endif
+
 namespace Mlt {
 
 const int kMaxImageDurationSecs = 3600 * 4;
@@ -67,7 +75,7 @@ public:
 
     virtual QObject *videoWidget() = 0;
     virtual int setProducer(Mlt::Producer *, bool isMulti = false);
-    virtual int open(const QString &url, const QString &urlToSave);
+    virtual int open(const QString &url, const QString &urlToSave, bool skipConvert = false);
     bool openXML(const QString &filename);
     virtual void close();
     virtual int displayWidth() const = 0;
@@ -86,7 +94,7 @@ public:
     virtual void refreshConsumer(bool scrubAudio = false);
     bool saveXML(const QString &filename, Service *service = nullptr, bool withRelativePaths = true,
                  QTemporaryFile *tempFile = nullptr, bool proxy = false, QString projectNote = QString());
-    QString XML(Service *service = nullptr, bool withProfile = false, bool withMetadata = false);
+    QString XML(Service *service = nullptr, bool withProfile = false, bool withMetadata = true);
     int consumerChanged();
     void setProfile(const QString &profile_name);
     void setAudioChannels(int audioChannels);
