@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2021 Meltytech, LLC
+ * Copyright (c) 2014-2023 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,14 +26,14 @@
 #include <QDir>
 #include <QCoreApplication>
 #include <QUrl>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <Logger.h>
 #include <clocale>
 #include <utime.h>
 
-static QString getPrefix(const QString& name, const QString& value);
+static QString getPrefix(const QString &name, const QString &value);
 
-static bool isMltClass(const QStringRef& name)
+static bool isMltClass(const QString &name)
 {
     return name == "profile" || name == "producer" ||
            name == "filter" || name == "playlist" ||
@@ -42,15 +42,16 @@ static bool isMltClass(const QStringRef& name)
            name == "chain" || name == "link";
 }
 
-static bool isNetworkResource(const QString& string)
+static bool isNetworkResource(const QString &string)
 {
     // Check if it looks like a qualified URL. Try parsing it and see.
-    QRegExp schemaTest(QLatin1String("^[a-zA-Z]{2,}\\:.*"));
+    QRegularExpression schemaTest(QLatin1String("^[a-zA-Z]{2,}\\:.*"));
     // Not actually checking network URL due to latency and transience.
-    return (schemaTest.exactMatch(string) && QUrl(string).isValid() && !string.startsWith("plain:"));
+    return (schemaTest.match(string).hasMatch() && QUrl(string).isValid()
+            && !string.startsWith("plain:"));
 }
 
-static bool isNumericProperty(const QString& name)
+static bool isNumericProperty(const QString &name)
 {
     return  name == "length" || name == "geometry" ||
             name == "rect" || name == "warp_speed";
@@ -62,20 +63,19 @@ MltXmlChecker::MltXmlChecker()
     , m_hasEffects(false)
     , m_isCorrected(false)
     , m_isUpdated(false)
-    , m_usesLocale(false)
     , m_decimalPoint('.')
     , m_numericValueChanged(false)
 {
     m_unlinkedFilesModel.setColumnCount(ColumnCount);
 }
 
-QXmlStreamReader::Error MltXmlChecker::check(const QString& fileName)
+QXmlStreamReader::Error MltXmlChecker::check(const QString &fileName)
 {
     LOG_DEBUG() << "begin";
 
     QFile file(fileName);
     m_tempFile.reset(new QTemporaryFile(
-        QFileInfo(fileName).dir().filePath("shotcut-XXXXXX.mlt")));
+                         QFileInfo(fileName).dir().filePath("shotcut-XXXXXX.mlt")));
     if (file.open(QIODevice::ReadOnly | QIODevice::Text) && m_tempFile->open()) {
         m_tempFile->resize(0);
         m_fileInfo = QFileInfo(fileName);
@@ -84,25 +84,23 @@ QXmlStreamReader::Error MltXmlChecker::check(const QString& fileName)
         m_newXml.setAutoFormatting(true);
         m_newXml.setAutoFormattingIndent(2);
         if (m_xml.readNextStartElement()) {
-            if (m_xml.name() == "mlt") {
+            if (m_xml.name().toString() == "mlt") {
                 m_newXml.writeStartDocument();
                 m_newXml.writeCharacters("\n");
                 m_newXml.writeStartElement("mlt");
                 foreach (QXmlStreamAttribute a, m_xml.attributes()) {
                     if (a.name().toString().toUpper() == "LC_NUMERIC") {
                         QString value = a.value().toString().toUpper();
-                        // Determine whether this document uses a non-POSIX/-generic numeric locale.
-                        m_usesLocale = (value != "" && value != "C" && value != "POSIX" && QLocale().decimalPoint() != '.');
-                        // Upon correcting the document to conform to current system,
-                        // update the declared LC_NUMERIC.
-                        m_newXml.writeAttribute("LC_NUMERIC", m_usesLocale? QLocale().name() : "C");
+                        m_newXml.writeAttribute("LC_NUMERIC", "C");
+                        MLT.resetLocale();
+                        m_decimalPoint = '.';
                     } else if (a.name().toString().toLower() == "version") {
                         m_mltVersion = QVersionNumber::fromString(a.value());
                     } else if (a.name().toString().toLower() == "title") {
                         m_newXml.writeAttribute(a.name().toString(), "Shotcut version " SHOTCUT_VERSION);
                         auto parts = a.value().split(' ');
                         LOG_DEBUG() << parts;
-                        if (parts.size() > 2 && parts[1] == "version") {
+                        if (parts.size() > 2 && parts[1].toString() == "version") {
                             m_shotcutVersion = parts[2].toString();
                         }
                     } else {
@@ -112,24 +110,6 @@ QXmlStreamReader::Error MltXmlChecker::check(const QString& fileName)
                 if (!checkMltVersion()) {
                     return QXmlStreamReader::CustomError;
                 }
-                // We cannot apply the locale change to the session at this point
-                // because we are merely checking at this point and not loading.
-                // Save the current locale state.
-                bool isCLocale = (::qgetenv(MLT_LC_NAME).toUpper() == "C");
-                // Apply the chosen locale temporarily.
-                setLocale();
-                // Get the decimal point expected based on the current system
-                // locale or POSIX/C if the document is using POSIX.
-                m_decimalPoint = MLT.decimalPoint();
-                LOG_INFO() << "decimal point" << m_decimalPoint;
-                // Restore the current locale state.
-                if (isCLocale) {
-                    ::qputenv(MLT_LC_NAME, "C");
-                    ::setlocale(MLT_LC_CATEGORY, "C");
-                } else {
-                    ::qunsetenv(MLT_LC_NAME);
-                    ::setlocale(MLT_LC_CATEGORY, "");
-                }
 
                 readMlt();
                 m_newXml.writeEndElement();
@@ -158,21 +138,9 @@ QString MltXmlChecker::errorString() const
     return m_xml.errorString();
 }
 
-void MltXmlChecker::setLocale()
-{
-    // Returns whether this document uses a non-POSIX/-generic numeric locale.
-    if (m_usesLocale) {
-        ::qunsetenv(MLT_LC_NAME);
-        ::setlocale(MLT_LC_CATEGORY, "");
-    } else {
-        ::qputenv(MLT_LC_NAME, "C");
-        ::setlocale(MLT_LC_CATEGORY, "C");
-    }
-}
-
 void MltXmlChecker::readMlt()
 {
-    Q_ASSERT(m_xml.isStartElement() && m_xml.name() == "mlt");
+    Q_ASSERT(m_xml.isStartElement() && m_xml.name().toString() == "mlt");
     bool isPropertyElement = false;
 
     while (!m_xml.atEnd()) {
@@ -191,7 +159,8 @@ void MltXmlChecker::readMlt()
             m_newXml.writeEntityReference(m_xml.name().toString());
             break;
         case QXmlStreamReader::ProcessingInstruction:
-            m_newXml.writeProcessingInstruction(m_xml.processingInstructionTarget().toString(), m_xml.processingInstructionData().toString());
+            m_newXml.writeProcessingInstruction(m_xml.processingInstructionTarget().toString(),
+                                                m_xml.processingInstructionData().toString());
             break;
         case QXmlStreamReader::StartDocument:
             m_newXml.writeStartDocument(m_xml.documentVersion().toString(), m_xml.isStandaloneDocument());
@@ -204,24 +173,24 @@ void MltXmlChecker::readMlt()
             isPropertyElement = false;
             if (element == "property") {
                 isPropertyElement = true;
-                if (isMltClass(&mlt_class)) {
+                if (isMltClass(mlt_class)) {
                     const QString name = m_xml.attributes().value("name").toString();
                     m_properties << MltProperty(name, m_xml.readElementText());
                 }
             } else {
                 processProperties();
                 m_newXml.writeStartElement(m_xml.namespaceUri().toString(), element);
-                if (isMltClass(m_xml.name()))
+                if (isMltClass(m_xml.name().toString()))
                     mlt_class = element;
                 checkInAndOutPoints(); // This also copies the attributes.
             }
             break;
         }
         case QXmlStreamReader::EndElement:
-            if (m_xml.name() != "property") {
+            if (m_xml.name().toString() != "property") {
                 processProperties();
                 m_newXml.writeEndElement();
-                if (isMltClass(m_xml.name())) {
+                if (isMltClass(m_xml.name().toString())) {
                     mlt_class.clear();
                 }
             }
@@ -245,6 +214,8 @@ void MltXmlChecker::processProperties()
             mlt_service = p.second;
         } else if (p.first == kShotcutHashProperty) {
             m_resource.hash = p.second;
+        } else if (p.first.startsWith(kIsProxyProperty)) {
+            m_resource.isProxy = true;
         } else if (isNumericProperty(p.first)) {
             checkNumericString(p.second);
         } else if (p.first == "resource" && mlt_service == "webvfx" && fixWebVfxPath(p.second)) {
@@ -274,10 +245,13 @@ void MltXmlChecker::processProperties()
         replaceWebVfxCropFilters(mlt_service, newProperties);
         replaceWebVfxChoppyFilter(mlt_service, newProperties);
 #endif
-        if (Settings.proxyEnabled())
+        bool proxyEnabled = Settings.proxyEnabled();
+        if (proxyEnabled)
             checkForProxy(mlt_service, newProperties);
 
         // Second pass: amend property values.
+        bool relinkMismatch = !m_resource.hash.isEmpty() && !m_resource.newHash.isEmpty()
+                              && m_resource.hash != m_resource.newHash;
         m_properties = newProperties;
         newProperties.clear();
         foreach (MltProperty p, m_properties) {
@@ -291,8 +265,27 @@ void MltXmlChecker::processProperties()
             } else if (p.first == kShotcutDetailProperty) {
                 // We no longer save this (leaks absolute paths).
                 p.second.clear();
-            } else if (p.first == "audio_index" || p.first == "video_index") {
-                fixStreamIndex(p);
+            } else if (relinkMismatch && p.first == "audio_index") {
+                // Reset stream index properties if re-linked file is different.
+                p.second = QString::number(m_resource.audio_index);
+            } else if (relinkMismatch && p.first == "astream") {
+                p.second = "0";
+            } else if (relinkMismatch && p.first == "video_index") {
+                p.second = QString::number(m_resource.video_index);
+            } else if (relinkMismatch && p.first == "vstream") {
+                p.second = "0";
+            } else if (relinkMismatch && p.first.startsWith("meta.")) {
+                // Remove meta properties if re-linked file is different.
+                p.second.clear();
+            } else if ((proxyEnabled
+                        && m_resource.notProxyMeta
+                        && p.first.startsWith("meta.")) ||
+                       (!proxyEnabled
+                        && m_resource.isProxy
+                        && (p.first == kIsProxyProperty || p.first.startsWith("meta.")))) {
+                // Remove meta properties if they misrepresent proxy/original
+                p.second.clear();
+                m_isUpdated = true;
             }
 
             if (!p.second.isEmpty())
@@ -316,7 +309,7 @@ void MltXmlChecker::checkInAndOutPoints()
 
     // Fix numeric values of in and out point attributes.
     foreach (QXmlStreamAttribute a, m_xml.attributes()) {
-        if (a.name() == "in" || a.name() == "out") {
+        if (a.name().toString() == "in" || a.name().toString() == "out") {
             QString value = a.value().toString();
             if (checkNumericString(value)) {
                 m_newXml.writeAttribute(a.name().toString(), value);
@@ -327,7 +320,7 @@ void MltXmlChecker::checkInAndOutPoints()
     }
 }
 
-bool MltXmlChecker::checkNumericString(QString& value)
+bool MltXmlChecker::checkNumericString(QString &value)
 {
     // Determine if there is a decimal point inconsistent with locale.
     if (!value.contains(m_decimalPoint) &&
@@ -340,7 +333,7 @@ bool MltXmlChecker::checkNumericString(QString& value)
     return false;
 }
 
-bool MltXmlChecker::fixWebVfxPath(QString& resource)
+bool MltXmlChecker::fixWebVfxPath(QString &resource)
 {
     // The path, if absolute, should start with the Shotcut executable path.
     QFileInfo fi(resource);
@@ -371,7 +364,7 @@ bool MltXmlChecker::fixWebVfxPath(QString& resource)
     return false;
 }
 
-static QString getPrefix(const QString& name, const QString& value)
+static QString getPrefix(const QString &name, const QString &value)
 {
     int length = 0;
 
@@ -398,7 +391,7 @@ static QString getPrefix(const QString& name, const QString& value)
     return QString();
 }
 
-static QString getSuffix(const QString& name, const QString& value)
+static QString getSuffix(const QString &name, const QString &value)
 {
     // avformat is only using "resource"
     if (name == "resource") {
@@ -412,29 +405,29 @@ static QString getSuffix(const QString& name, const QString& value)
     return QString();
 }
 
-bool MltXmlChecker::readResourceProperty(const QString& name, QString& value)
+bool MltXmlChecker::readResourceProperty(const QString &name, QString &value)
 {
     if (mlt_class == "filter" || mlt_class == "transition" || mlt_class == "producer"
             || mlt_class == "chain" || mlt_class == "link")
-    if (name == "resource" || name == "src" || name == "filename"
-            || name == "luma" || name == "luma.resource" || name == "composite.luma"
-            || name == "producer.resource" || name == "av.file" || name == "warp_resource") {
+        if (name == "resource" || name == "src" || name == "filename"
+                || name == "luma" || name == "luma.resource" || name == "composite.luma"
+                || name == "producer.resource" || name == "av.file" || name == "warp_resource") {
 
-        // Handle special prefix such as "plain:" or speed.
-        m_resource.prefix = getPrefix(name, value);
-        m_resource.suffix = getSuffix(name, value);
-        auto filePath = value.mid(m_resource.prefix.size());
-        filePath = filePath.left(filePath.size() - m_resource.suffix.size());
-        // Save the resource name (minus prefix) for later check for unlinked files.
-        m_resource.info.setFile(filePath);
-        if (!isNetworkResource(value) && m_resource.info.isRelative() && !Util::hasDriveLetter(value))
-            m_resource.info.setFile(m_fileInfo.canonicalPath(), m_resource.info.filePath());
-        return true;
-    }
+            // Handle special prefix such as "plain:" or speed.
+            m_resource.prefix = getPrefix(name, value);
+            m_resource.suffix = getSuffix(name, value);
+            auto filePath = value.mid(m_resource.prefix.size());
+            filePath = filePath.left(filePath.size() - m_resource.suffix.size());
+            // Save the resource name (minus prefix) for later check for unlinked files.
+            m_resource.info.setFile(filePath);
+            if (!isNetworkResource(value) && m_resource.info.isRelative() && !Util::hasDriveLetter(value))
+                m_resource.info.setFile(m_fileInfo.canonicalPath(), m_resource.info.filePath());
+            return true;
+        }
     return false;
 }
 
-void MltXmlChecker::checkGpuEffects(const QString& mlt_service)
+void MltXmlChecker::checkGpuEffects(const QString &mlt_service)
 {
     // Check for GPU effects.
     if (!MLT.isAudioFilter(mlt_service))
@@ -443,54 +436,55 @@ void MltXmlChecker::checkGpuEffects(const QString& mlt_service)
         m_needsGPU = true;
 }
 
-void MltXmlChecker::checkCpuEffects(const QString& mlt_service)
+void MltXmlChecker::checkCpuEffects(const QString &mlt_service)
 {
-    if (mlt_service.startsWith("dynamictext") || mlt_service.startsWith("vidstab"))
+    if (mlt_service.startsWith("frei0r.cairoblend") || mlt_service.startsWith("choppy"))
         m_needsCPU = true;
 }
 
-void MltXmlChecker::checkUnlinkedFile(const QString& mlt_service)
+void MltXmlChecker::checkUnlinkedFile(const QString &mlt_service)
 {
     // Check for an unlinked file.
     const QString fileName = m_resource.info.fileName();
     const QString filePath = QDir::toNativeSeparators(m_resource.info.filePath());
     // not the color producer
     if (!mlt_service.isEmpty() && mlt_service != "color" && mlt_service != "colour")
-    // not a builtin luma wipe file
-    if ((mlt_service != "luma" && mlt_service != "movit.luma_mix") || !fileName.startsWith('%'))
-    // not a Stabilize filter without Analyze results
-    if (fileName != "vidstab.trf")
-    // not the generic <producer> resource
-    if (fileName != "<producer>")
-    // not an invalid <tractor>
-    if (fileName != "<tractor>")
-    // not an invalid blank
-    if (mlt_service != "blank" || fileName != "blank")
-    // not a URL
-    if (!m_resource.info.filePath().isEmpty() && !isNetworkResource(m_resource.info.filePath()))
-    // not an image sequence
-    if ((mlt_service != "pixbuf" && mlt_service != "qimage") || fileName.indexOf('%') == -1)
-    // file does not exist
-    if (!m_resource.info.exists())
-    // not already in the model
-    if (m_unlinkedFilesModel.findItems(filePath,
-            Qt::MatchFixedString | Qt::MatchCaseSensitive).isEmpty()) {
-        LOG_ERROR() << "file not found: " << m_resource.info.filePath();
-        QIcon icon(":/icons/oxygen/32x32/status/task-reject.png");
-        QStandardItem* item = new QStandardItem(icon, filePath);
-        item->setToolTip(item->text());
-        item->setData(m_resource.hash, ShotcutHashRole);
-        m_unlinkedFilesModel.appendRow(item);
-    }
+        // not a builtin luma wipe file
+        if ((mlt_service != "luma" && mlt_service != "movit.luma_mix") || !fileName.startsWith('%'))
+            // not a Stabilize filter without Analyze results
+            if (fileName != "vidstab.trf")
+                // not the generic <producer> resource
+                if (fileName != "<producer>")
+                    // not an invalid <tractor>
+                    if (fileName != "<tractor>")
+                        // not an invalid blank
+                        if (mlt_service != "blank" || fileName != "blank")
+                            // not a URL
+                            if (!m_resource.info.filePath().isEmpty() && !isNetworkResource(m_resource.info.filePath()))
+                                // not an image sequence
+                                if ((mlt_service != "pixbuf" && mlt_service != "qimage") || fileName.indexOf('%') == -1)
+                                    // file does not exist
+                                    if (!m_resource.info.exists())
+                                        // not already in the model
+                                        if (m_unlinkedFilesModel.findItems(filePath,
+                                                                           Qt::MatchFixedString | Qt::MatchCaseSensitive).isEmpty()) {
+                                            LOG_ERROR() << "file not found: " << m_resource.info.filePath();
+                                            QIcon icon(":/icons/oxygen/32x32/status/task-reject.png");
+                                            QStandardItem *item = new QStandardItem(icon, filePath);
+                                            item->setToolTip(item->text());
+                                            item->setData(m_resource.hash, ShotcutHashRole);
+                                            m_unlinkedFilesModel.appendRow(item);
+                                        }
 }
 
-bool MltXmlChecker::fixUnlinkedFile(QString& value)
+bool MltXmlChecker::fixUnlinkedFile(QString &value)
 {
     // Replace unlinked files if model is populated with replacements.
     for (int row = 0; row < m_unlinkedFilesModel.rowCount(); ++row) {
-        const QStandardItem* replacement = m_unlinkedFilesModel.item(row, ReplacementColumn);
+        const QStandardItem *replacement = m_unlinkedFilesModel.item(row, ReplacementColumn);
         if (replacement && !replacement->text().isEmpty() &&
-                m_unlinkedFilesModel.item(row, MissingColumn)->text() == QDir::toNativeSeparators(m_resource.info.filePath())) {
+                m_unlinkedFilesModel.item(row,
+                                          MissingColumn)->text() == QDir::toNativeSeparators(m_resource.info.filePath())) {
             m_resource.info.setFile(replacement->text());
             m_resource.newDetail = replacement->text();
             m_resource.newHash = replacement->data(ShotcutHashRole).toString();
@@ -514,20 +508,7 @@ bool MltXmlChecker::fixUnlinkedFile(QString& value)
     return false;
 }
 
-void MltXmlChecker::fixStreamIndex(MltProperty& property)
-{
-    // Remove a stream index property if re-linked file is different.
-    if (!m_resource.hash.isEmpty() && !m_resource.newHash.isEmpty()
-        && m_resource.hash != m_resource.newHash) {
-        if (property.first == "audio_index") {
-            property.second = QString::number(m_resource.audio_index);
-        } else if (property.first == "video_index") {
-            property.second = QString::number(m_resource.video_index);
-        }
-    }
-}
-
-bool MltXmlChecker::fixVersion1701WindowsPathBug(QString& value)
+bool MltXmlChecker::fixVersion1701WindowsPathBug(QString &value)
 {
     if (value.size() >= 3 && value[0] == '/' && value[2] == ':') {
         value.remove(0, 1);
@@ -537,11 +518,11 @@ bool MltXmlChecker::fixVersion1701WindowsPathBug(QString& value)
     return false;
 }
 
-void MltXmlChecker::checkIncludesSelf(QVector<MltProperty>& properties)
+void MltXmlChecker::checkIncludesSelf(QVector<MltProperty> &properties)
 {
     if (m_resource.info.canonicalFilePath() == m_fileInfo.canonicalFilePath()) {
         LOG_WARNING() << "This project tries to include itself; breaking that!";
-        for (auto& p : properties) {
+        for (auto &p : properties) {
             if (p.first == "mlt_service")
                 p.second.clear();
             else if (p.first == "resource")
@@ -552,11 +533,12 @@ void MltXmlChecker::checkIncludesSelf(QVector<MltProperty>& properties)
     }
 }
 
-void MltXmlChecker::checkLumaAlphaOver(const QString& mlt_service, QVector<MltXmlChecker::MltProperty>& properties)
+void MltXmlChecker::checkLumaAlphaOver(const QString &mlt_service,
+                                       QVector<MltXmlChecker::MltProperty> &properties)
 {
     if (mlt_service == "luma") {
         bool found = false;
-        for (auto& p : properties) {
+        for (auto &p : properties) {
             if (p.first == "alpha_over") {
                 found = true;
             }
@@ -568,11 +550,12 @@ void MltXmlChecker::checkLumaAlphaOver(const QString& mlt_service, QVector<MltXm
     }
 }
 
-void MltXmlChecker::replaceWebVfxCropFilters(QString& mlt_service, QVector<MltXmlChecker::MltProperty>& properties)
+void MltXmlChecker::replaceWebVfxCropFilters(QString &mlt_service,
+                                             QVector<MltXmlChecker::MltProperty> &properties)
 {
     if (mlt_service == "webvfx") {
         auto isCrop = false;
-        for (auto& p : properties) {
+        for (auto &p : properties) {
             if (p.first == "shotcut:filter" && p.second == "webvfxCircularFrame") {
                 p.second = "cropCircle";
                 properties << MltProperty("circle", "1");
@@ -587,13 +570,13 @@ void MltXmlChecker::replaceWebVfxCropFilters(QString& mlt_service, QVector<MltXm
         }
         if (isCrop) {
             mlt_service = "qtcrop";
-            for (auto& p : properties) {
+            for (auto &p : properties) {
                 if (p.first == "resource") {
                     properties.removeOne(p);
                     break;
                 }
             }
-            for (auto& p : properties) {
+            for (auto &p : properties) {
                 if (p.first == "mlt_service") {
                     p.second = "qtcrop";
                     break;
@@ -603,12 +586,13 @@ void MltXmlChecker::replaceWebVfxCropFilters(QString& mlt_service, QVector<MltXm
     }
 }
 
-void MltXmlChecker::replaceWebVfxChoppyFilter(QString& mlt_service, QVector<MltXmlChecker::MltProperty>& properties)
+void MltXmlChecker::replaceWebVfxChoppyFilter(QString &mlt_service,
+                                              QVector<MltXmlChecker::MltProperty> &properties)
 {
     if (mlt_service == "webvfx") {
         auto isChoppy = false;
         QString shotcutFilter;
-        for (auto& p : properties) {
+        for (auto &p : properties) {
             if (p.first == "shotcut:filter") {
                 shotcutFilter = p.second;
                 if (p.second == "webvfxChoppy") {
@@ -620,13 +604,13 @@ void MltXmlChecker::replaceWebVfxChoppyFilter(QString& mlt_service, QVector<MltX
         }
         if (isChoppy) {
             mlt_service = "choppy";
-            for (auto& p : properties) {
+            for (auto &p : properties) {
                 if (p.first == "resource") {
                     properties.removeOne(p);
                     break;
                 }
             }
-            for (auto& p : properties) {
+            for (auto &p : properties) {
                 if (p.first == "mlt_service") {
                     p.second = "choppy";
                     break;
@@ -635,7 +619,7 @@ void MltXmlChecker::replaceWebVfxChoppyFilter(QString& mlt_service, QVector<MltX
         } else if (shotcutFilter.isEmpty()) {
             mlt_service = "qtext";
             m_isUpdated = true;
-            for (auto& p : properties) {
+            for (auto &p : properties) {
                 if (p.first == "resource") {
                     auto pathName = p.second;
                     auto plain = QLatin1String("plain:");
@@ -654,7 +638,7 @@ void MltXmlChecker::replaceWebVfxChoppyFilter(QString& mlt_service, QVector<MltX
                     break;
                 }
             }
-            for (auto& p : properties) {
+            for (auto &p : properties) {
                 if (p.first == "mlt_service") {
                     p.second = "qtext";
                     break;
@@ -665,14 +649,15 @@ void MltXmlChecker::replaceWebVfxChoppyFilter(QString& mlt_service, QVector<MltX
     }
 }
 
-void MltXmlChecker::checkForProxy(const QString& mlt_service, QVector<MltXmlChecker::MltProperty>& properties)
+void MltXmlChecker::checkForProxy(const QString &mlt_service,
+                                  QVector<MltXmlChecker::MltProperty> &properties)
 {
     bool isTimewarp = mlt_service == "timewarp";
     if (mlt_service.startsWith("avformat") || isTimewarp) {
         QString resource;
         QString hash;
         QString speed = "1";
-        for (auto& p : properties) {
+        for (auto &p : properties) {
             if ((!isTimewarp && p.first == "resource") || p.first == "warp_resource") {
                 QFileInfo info(p.second);
                 if (info.isRelative())
@@ -689,14 +674,16 @@ void MltXmlChecker::checkForProxy(const QString& mlt_service, QVector<MltXmlChec
 
         // Use GoPro LRV if available
         if (QFile::exists(ProxyManager::GoProProxyFilePath(resource))) {
-            for (auto& p : properties) {
+            for (auto &p : properties) {
                 if (p.first == "resource") {
                     p.second = ProxyManager::GoProProxyFilePath(resource);
                     if (isTimewarp) {
-                        p.second = QString("%1:%2").arg(speed).arg(p.second);
+                        p.second = QString("%1:%2").arg(speed, p.second);
                     }
                     properties << MltProperty(kIsProxyProperty, "1");
+                    properties << MltProperty(kMetaProxyProperty, "1");
                     properties << MltProperty(kOriginalResourceProperty, resource);
+                    m_resource.notProxyMeta = !m_resource.isProxy;
                     m_isUpdated = true;
                     return;
                 }
@@ -710,7 +697,7 @@ void MltXmlChecker::checkForProxy(const QString& mlt_service, QVector<MltXmlChec
         if (proxyDir.exists(fileName) || projectDir.exists(fileName)) {
             ::utime(proxyDir.filePath(fileName).toUtf8().constData(), nullptr);
             ::utime(projectDir.filePath(fileName).toUtf8().constData(), nullptr);
-            for (auto& p : properties) {
+            for (auto &p : properties) {
                 if (p.first == "resource") {
                     if (projectDir.exists(fileName)) {
                         p.second = projectDir.filePath(fileName);
@@ -718,19 +705,22 @@ void MltXmlChecker::checkForProxy(const QString& mlt_service, QVector<MltXmlChec
                         p.second = proxyDir.filePath(fileName);
                     }
                     if (isTimewarp) {
-                        p.second = QString("%1:%2").arg(speed).arg(p.second);
+                        p.second = QString("%1:%2").arg(speed, p.second);
                     }
                     break;
                 }
             }
             properties << MltProperty(kIsProxyProperty, "1");
+            properties << MltProperty(kMetaProxyProperty, "1");
             properties << MltProperty(kOriginalResourceProperty, resource);
+            m_resource.notProxyMeta = !m_resource.isProxy;
             m_isUpdated = true;
         }
-    } else if ((mlt_service == "qimage" || mlt_service == "pixbuf") && !properties.contains(MltProperty(kShotcutSequenceProperty, "1"))) {
+    } else if ((mlt_service == "qimage" || mlt_service == "pixbuf")
+               && !properties.contains(MltProperty(kShotcutSequenceProperty, "1"))) {
         QString resource;
         QString hash;
-        for (auto& p : properties) {
+        for (auto &p : properties) {
             if (p.first == "resource") {
                 QFileInfo info(p.second);
                 if (info.isRelative())
@@ -749,7 +739,7 @@ void MltXmlChecker::checkForProxy(const QString& mlt_service, QVector<MltXmlChec
         if (proxyDir.exists(fileName) || projectDir.exists(fileName)) {
             ::utime(proxyDir.filePath(fileName).toUtf8().constData(), nullptr);
             ::utime(projectDir.filePath(fileName).toUtf8().constData(), nullptr);
-            for (auto& p : properties) {
+            for (auto &p : properties) {
                 if (p.first == "resource") {
                     if (projectDir.exists(fileName)) {
                         p.second = projectDir.filePath(fileName);
@@ -760,7 +750,9 @@ void MltXmlChecker::checkForProxy(const QString& mlt_service, QVector<MltXmlChec
                 }
             }
             properties << MltProperty(kIsProxyProperty, "1");
+            properties << MltProperty(kMetaProxyProperty, "1");
             properties << MltProperty(kOriginalResourceProperty, resource);
+            m_resource.notProxyMeta = !m_resource.isProxy;
             m_isUpdated = true;
         }
     }
