@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2019 Meltytech, LLC
+ * Copyright (c) 2018-2023 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
 #include <Logger.h>
 
 #include <QTimer>
+#include <QRegularExpression>
 
 static const quintptr NO_PARENT_ID = quintptr(-1);
 
@@ -71,14 +72,112 @@ QVariant KeyframesModel::data(const QModelIndex &index, int role) const
                     switch (role) {
                     case Qt::DisplayRole:
                     case NameRole: {
-                        QString type = tr("Hold");
+                        QString type = tr("Linear");
                         switch (const_cast<Mlt::Animation &>(animation).key_get_type(index.row())) {
-                        case mlt_keyframe_linear:
-                            type = tr("Linear");
+                        case mlt_keyframe_discrete:
+                            type = tr("Hold");
                             break;
+#if LIBMLT_VERSION_INT >= ((7<<16)+(21<<8))
+                        case mlt_keyframe_smooth_loose:
+                        case mlt_keyframe_smooth_natural:
+                        case mlt_keyframe_smooth_tight:
+                            type = tr("Smooth");
+                            break;
+                        case mlt_keyframe_sinusoidal_in:
+                            type = tr("Ease In Sinusoidal");
+                            break;
+                        case mlt_keyframe_sinusoidal_out:
+                            type = tr("Ease Out Sinusoidal");
+                            break;
+                        case mlt_keyframe_sinusoidal_in_out:
+                            type = tr("Ease In/Out Sinusoidal");
+                            break;
+                        case mlt_keyframe_quadratic_in:
+                            type = tr("Ease In Quadratic");
+                            break;
+                        case mlt_keyframe_quadratic_out:
+                            type = tr("Ease Out Quadratic");
+                            break;
+                        case mlt_keyframe_quadratic_in_out:
+                            type = tr("Ease In/Out Quadratic");
+                            break;
+                        case mlt_keyframe_cubic_in:
+                            type = tr("Ease In Cubic");
+                            break;
+                        case mlt_keyframe_cubic_out:
+                            type = tr("Ease Out Cubic");
+                            break;
+                        case mlt_keyframe_cubic_in_out:
+                            type = tr("Ease In/Out Cubic");
+                            break;
+                        case mlt_keyframe_quartic_in:
+                            type = tr("Ease In Quartic");
+                            break;
+                        case mlt_keyframe_quartic_out:
+                            type = tr("Ease Out Quartic");
+                            break;
+                        case mlt_keyframe_quartic_in_out:
+                            type = tr("Ease In/Out Quartic");
+                            break;
+                        case mlt_keyframe_quintic_in:
+                            type = tr("Ease In Quintic");
+                            break;
+                        case mlt_keyframe_quintic_out:
+                            type = tr("Ease Out Quintic");
+                            break;
+                        case mlt_keyframe_quintic_in_out:
+                            type = tr("Ease In/Out Quintic");
+                            break;
+                        case mlt_keyframe_exponential_in:
+                            type = tr("Ease In Exponential");
+                            break;
+                        case mlt_keyframe_exponential_out:
+                            type = tr("Ease Out Exponential");
+                            break;
+                        case mlt_keyframe_exponential_in_out:
+                            type = tr("Ease In/Out Exponential");
+                            break;
+                        case mlt_keyframe_circular_in:
+                            type = tr("Ease In Circular");
+                            break;
+                        case mlt_keyframe_circular_out:
+                            type = tr("Ease Out Circular");
+                            break;
+                        case mlt_keyframe_circular_in_out:
+                            type = tr("Ease In/Out Circular");
+                            break;
+                        case mlt_keyframe_back_in:
+                            type = tr("Ease In Back");
+                            break;
+                        case mlt_keyframe_back_out:
+                            type = tr("Ease Out Back");
+                            break;
+                        case mlt_keyframe_back_in_out:
+                            type = tr("Ease In/Out Back");
+                            break;
+                        case mlt_keyframe_elastic_in:
+                            type = tr("Ease In Elastic");
+                            break;
+                        case mlt_keyframe_elastic_out:
+                            type = tr("Ease Out Elastic");
+                            break;
+                        case mlt_keyframe_elastic_in_out:
+                            type = tr("Ease In/Out Elastic");
+                            break;
+                        case mlt_keyframe_bounce_in:
+                            type = tr("Ease In Bounce");
+                            break;
+                        case mlt_keyframe_bounce_out:
+                            type = tr("Ease Out Bounce");
+                            break;
+                        case mlt_keyframe_bounce_in_out:
+                            type = tr("Ease In/Out Bounce");
+                            break;
+#else
                         case mlt_keyframe_smooth:
                             type = tr("Smooth");
                             break;
+#endif
                         default:
                             break;
                         }
@@ -90,7 +189,15 @@ QVariant KeyframesModel::data(const QModelIndex &index, int role) const
                     case FrameNumberRole:
                         return position;
                     case KeyframeTypeRole:
+                        if (index.row() >= animation.key_count() - 1) {
+                            return DiscreteInterpolation;
+                        }
                         return const_cast<Mlt::Animation &>(animation).key_get_type(index.row());
+                    case PrevKeyframeTypeRole:
+                        if (index.row() <= 0) {
+                            return DiscreteInterpolation;
+                        }
+                        return const_cast<Mlt::Animation &>(animation).key_get_type(index.row() - 1);
                     case NumericValueRole:
                         return m_filter->getDouble(name, position);
                     case MinimumFrameRole: {
@@ -225,6 +332,7 @@ QHash<int, QByteArray> KeyframesModel::roleNames() const
     roles[HighestValueRole] = "highest";
     roles[FrameNumberRole]  = "frame";
     roles[KeyframeTypeRole] = "interpolation";
+    roles[PrevKeyframeTypeRole] = "prevInterpolation";
     roles[NumericValueRole] = "value";
     roles[MinimumFrameRole] = "minimumFrame";
     roles[MaximumFrameRole] = "maximumFrame";
@@ -265,16 +373,19 @@ bool KeyframesModel::remove(int parameterIndex, int keyframeIndex)
             error = animation.remove(frame_num);
             if (!error) {
                 animation.interpolate();
+                m_filter->updateChangeCommand(name);
                 beginRemoveRows(index(parameterIndex), keyframeIndex, keyframeIndex);
                 m_keyframeCounts[parameterIndex] -= 1;
                 endRemoveRows();
-                foreach (name, m_metadata->keyframes()->parameter(
-                             m_metadataIndex[parameterIndex])->gangedProperties()) {
-                    Mlt::Animation animation = m_filter->getAnimation(name);
-                    if (animation.is_valid() && !animation.remove(frame_num))
+                for (auto &key : gangedProperties(parameterIndex)) {
+                    Mlt::Animation animation = m_filter->getAnimation(key);
+                    if (animation.is_valid() && !animation.remove(frame_num)) {
                         animation.interpolate();
+                        m_filter->updateChangeCommand(key);
+                    }
                 }
-
+                mlt_event_data eventData = mlt_event_data_from_string(name.toUtf8().constData());
+                mlt_events_fire(m_filter->service().get_properties(), "property-changed", eventData);
                 QModelIndex modelIndex;
                 if (keyframeIndex > 0) {
                     modelIndex = index(keyframeIndex - 1, 0, index(parameterIndex));
@@ -360,13 +471,20 @@ bool KeyframesModel::setInterpolation(int parameterIndex, int keyframeIndex, Int
         if (animation.is_valid()) {
             if (!animation.key_set_type(keyframeIndex, mlt_keyframe_type(type))) {
 //                LOG_DEBUG() << "keyframe index" << keyframeIndex << "keyframe type" << type;
-                foreach (name, m_metadata->keyframes()->parameter(
-                             m_metadataIndex[parameterIndex])->gangedProperties()) {
-                    Mlt::Animation animation = m_filter->getAnimation(name);
-                    animation.key_set_type(keyframeIndex, mlt_keyframe_type(type));
+                m_filter->updateChangeCommand(name);
+                for (auto &key : gangedProperties(parameterIndex)) {
+                    Mlt::Animation animation = m_filter->getAnimation(key);
+                    if (animation.is_valid()) {
+                        animation.key_set_type(keyframeIndex, mlt_keyframe_type(type));
+                        m_filter->updateChangeCommand(key);
+                    }
                 }
+                mlt_event_data eventData = mlt_event_data_from_string(name.toUtf8().constData());
+                mlt_events_fire(m_filter->service().get_properties(), "property-changed", eventData);
                 QModelIndex modelIndex = index(keyframeIndex, 0, index(parameterIndex));
                 emit dataChanged(modelIndex, modelIndex, QVector<int>() << KeyframeTypeRole << NameRole);
+                QModelIndex nextModelIndex = index(keyframeIndex + 1, 0, index(parameterIndex));
+                emit dataChanged(nextModelIndex, nextModelIndex, QVector<int>() << PrevKeyframeTypeRole);
                 error = false;
                 emit m_filter->changed(name.toUtf8().constData());
                 emit m_filter->propertyChanged(name.toUtf8().constData());
@@ -419,12 +537,16 @@ void KeyframesModel::setKeyframePosition(int parameterIndex, int keyframeIndex,
         return;
     }
 
-    foreach (name, m_metadata->keyframes()->parameter(
-                 m_metadataIndex[parameterIndex])->gangedProperties()) {
-        Mlt::Animation animation = m_filter->getAnimation(name);
-        if (animation.is_valid())
+    m_filter->updateChangeCommand(name);
+    for (auto &key : gangedProperties(parameterIndex)) {
+        Mlt::Animation animation = m_filter->getAnimation(key);
+        if (animation.is_valid()) {
             animation.key_set_frame(keyframeIndex, position);
+            m_filter->updateChangeCommand(key);
+        }
     }
+    mlt_event_data eventData = mlt_event_data_from_string(name.toUtf8().constData());
+    mlt_events_fire(m_filter->service().get_properties(), "property-changed", eventData);
     QModelIndex modelIndex = index(keyframeIndex, 0, index(parameterIndex));
     emit dataChanged(modelIndex, modelIndex, QVector<int>() << FrameNumberRole << NameRole);
     updateNeighborsMinMax(parameterIndex, keyframeIndex);
@@ -438,9 +560,11 @@ void KeyframesModel::addKeyframe(int parameterIndex, double value, int position,
     if (m_filter && parameterIndex < m_propertyNames.count()) {
         QString name = m_propertyNames[parameterIndex];
         m_filter->set(name, value, position,  mlt_keyframe_type(type));
-        foreach (name, m_metadata->keyframes()->parameter(
-                     m_metadataIndex[parameterIndex])->gangedProperties())
-            m_filter->set(name, value, position,  mlt_keyframe_type(type));
+        m_filter->updateChangeCommand(name);
+        for (auto &key : gangedProperties(parameterIndex)) {
+            m_filter->set(key, value, position,  mlt_keyframe_type(type));
+            m_filter->updateChangeCommand(key);
+        }
     }
 }
 
@@ -449,6 +573,7 @@ void KeyframesModel::addKeyframe(int parameterIndex, int position)
     if (m_filter && parameterIndex < m_propertyNames.count()) {
         QString name = m_propertyNames[parameterIndex];
         auto parameter = m_metadata->keyframes()->parameter(m_metadataIndex[parameterIndex]);
+
         if (parameter->isRectangle()) {
             auto value = m_filter->getRect(name, position);
             Mlt::Animation anim = m_filter->getAnimation(name);
@@ -457,6 +582,8 @@ void KeyframesModel::addKeyframe(int parameterIndex, int position)
                 m_filter->blockSignals(true);
                 m_filter->set(name, value, position, keyframeType);
                 m_filter->blockSignals(false);
+                m_filter->updateChangeCommand(name);
+                emit keyframeAdded(name, position);
             }
         } else if (parameter->isCurve()) {
             // Get the value from the existing position.
@@ -475,13 +602,31 @@ void KeyframesModel::addKeyframe(int parameterIndex, int position)
                 // because it did not receive a "consumer-frame-show" event for it.
                 m_filter->blockSignals(true);
                 m_filter->set(name, value, position, keyframeType);
+                m_filter->updateChangeCommand(name);
                 for (auto &key : parameter->gangedProperties()) {
                     value = m_filter->getDouble(key, position);
                     m_filter->set(key, value, position, keyframeType);
+                    m_filter->updateChangeCommand(key);
+                }
+                m_filter->blockSignals(false);
+                emit keyframeAdded(name, position);
+            }
+        } else if (parameter->isColor()) {
+            // Color values
+            auto value = m_filter->getColor(name, position);
+            Mlt::Animation anim = m_filter->getAnimation(name);
+            if (anim.is_valid() && !anim.is_key(position)) {
+                mlt_keyframe_type keyframeType = m_filter->getKeyframeType(anim, position, mlt_keyframe_type(-1));
+                m_filter->blockSignals(true);
+                m_filter->set(name, value, position, keyframeType);
+                m_filter->updateChangeCommand(name);
+                for (auto &key : parameter->gangedProperties()) {
+                    value = m_filter->get(key, position);
+                    m_filter->set(key, value, position, keyframeType);
+                    m_filter->updateChangeCommand(key);
                 }
                 m_filter->blockSignals(false);
             }
-        } else {
             emit keyframeAdded(name, position);
         }
         onFilterChanged(name);
@@ -521,10 +666,11 @@ void KeyframesModel::setKeyframeValue(int parameterIndex, int keyframeIndex, dou
     mlt_keyframe_type type = animation.key_get_type(keyframeIndex);
     m_filter->service().anim_set(name.toUtf8().constData(), value, position, m_filter->duration(),
                                  type);
-    foreach (name, m_metadata->keyframes()->parameter(
-                 m_metadataIndex[parameterIndex])->gangedProperties())
-        m_filter->service().anim_set(name.toUtf8().constData(), value, position, m_filter->duration(),
-                                     type);
+    m_filter->updateChangeCommand(name);
+    for (auto &key : gangedProperties(parameterIndex)) {
+        m_filter->service().anim_set(key.toUtf8().constData(), value, position, m_filter->duration(), type);
+        m_filter->updateChangeCommand(key);
+    }
     emit m_filter->changed(name.toUtf8().constData());
     emit m_filter->propertyChanged(name.toUtf8().constData());
     QModelIndex modelIndex = index(keyframeIndex, 0, index(parameterIndex));
@@ -570,11 +716,11 @@ void KeyframesModel::setKeyframeValuePosition(int parameterIndex, int keyframeIn
             LOG_ERROR() << "Failed to set position" << parameterIndex << keyframeIndex << position;
             return;
         }
-        foreach (name, m_metadata->keyframes()->parameter(
-                     m_metadataIndex[parameterIndex])->gangedProperties()) {
-            Mlt::Animation animation = m_filter->getAnimation(name);
-            if (animation.is_valid())
+        for (auto &key : gangedProperties(parameterIndex)) {
+            Mlt::Animation animation = m_filter->getAnimation(key);
+            if (animation.is_valid()) {
                 animation.key_set_frame(keyframeIndex, position);
+            }
         }
         roles << FrameNumberRole;
         updateNeighborsMinMax(parameterIndex, keyframeIndex);
@@ -583,10 +729,11 @@ void KeyframesModel::setKeyframeValuePosition(int parameterIndex, int keyframeIn
     mlt_keyframe_type type = animation.key_get_type(keyframeIndex);
     m_filter->service().anim_set(name.toUtf8().constData(), value, position, m_filter->duration(),
                                  type);
-    foreach (name, m_metadata->keyframes()->parameter(
-                 m_metadataIndex[parameterIndex])->gangedProperties())
-        m_filter->service().anim_set(name.toUtf8().constData(), value, position, m_filter->duration(),
-                                     type);
+    m_filter->updateChangeCommand(name);
+    for (auto &key : gangedProperties(parameterIndex)) {
+        m_filter->service().anim_set(key.toUtf8().constData(), value, position, m_filter->duration(), type);
+        m_filter->updateChangeCommand(key);
+    }
     emit m_filter->changed(name.toUtf8().constData());
     emit m_filter->propertyChanged(name.toUtf8().constData());
     roles << NumericValueRole << NameRole;
@@ -624,8 +771,10 @@ void KeyframesModel::removeAdvancedKeyframes()
             QString name = m_metadata->keyframes()->parameter(i)->property();
             if (m_filter->keyframeCount(name) > 0) {
                 m_filter->set(name, m_filter->get(name, 0));
+                m_filter->updateChangeCommand(name);
                 for (auto &key : m_metadata->keyframes()->parameter(i)->gangedProperties()) {
                     m_filter->set(key, m_filter->get(key, 0));
+                    m_filter->updateChangeCommand(key);
                 }
             }
         }
@@ -666,6 +815,29 @@ void KeyframesModel::removeSimpleKeyframes()
                 }
                 if (clearKeyframes) {
                     m_filter->set(name, firstValue);
+                    m_filter->updateChangeCommand(name);
+                }
+            } else if (parameter->isColor()) {
+                auto firstValue = m_filter->getColor(name, 0);
+                Mlt::Animation anim = m_filter->getAnimation(name);
+                if (anim.is_valid()) {
+                    for (int k = 1; k < anim.key_count(); k++) {
+                        auto value = m_filter->getColor(name, anim.key_get_frame(k));
+                        if (value != firstValue) {
+                            clearKeyframes = false;
+                            break;
+                        }
+                    }
+                }
+                if (clearKeyframes) {
+                    m_filter->set(name, firstValue);
+                    m_filter->updateChangeCommand(name);
+                    m_filter->blockSignals(true);
+                    for (auto &key : parameter->gangedProperties()) {
+                        m_filter->set(key, m_filter->getColor(key, 0));
+                        m_filter->updateChangeCommand(key);
+                    }
+                    m_filter->blockSignals(false);
                 }
             } else {
                 double firstValue = m_filter->getDouble(name, 0);
@@ -681,9 +853,11 @@ void KeyframesModel::removeSimpleKeyframes()
                 }
                 if (clearKeyframes) {
                     m_filter->set(name, firstValue);
+                    m_filter->updateChangeCommand(name);
                     m_filter->blockSignals(true);
                     for (auto &key : parameter->gangedProperties()) {
                         m_filter->set(key, m_filter->getDouble(key, 0));
+                        m_filter->updateChangeCommand(key);
                     }
                     m_filter->blockSignals(false);
                 }
@@ -766,6 +940,7 @@ void KeyframesModel::trimFilterIn(int in)
         Mlt::Filter filter = service;
         MLT.adjustFilter(&filter, filter.get_in(), filter.get_out(), in - filter.get_in(), 0,
                          in - filter.get_in());
+        m_filter->updateChangeCommand("in");
     }
 }
 
@@ -775,6 +950,7 @@ void KeyframesModel::trimFilterOut(int out)
     if (service.is_valid() && service.type() == mlt_service_filter_type) {
         Mlt::Filter filter = service;
         MLT.adjustFilter(&filter, filter.get_in(), filter.get_out(), 0, filter.get_out() - out, 0);
+        m_filter->updateChangeCommand("out");
     }
 }
 
@@ -798,3 +974,8 @@ void KeyframesModel::updateNeighborsMinMax(int parameterIndex, int keyframeIndex
         emit dataChanged(modelIndex, modelIndex, QVector<int>() << MinimumFrameRole);
     }
 }
+
+QStringList KeyframesModel::gangedProperties(int parameterIndex) const
+{
+    return m_metadata->keyframes()->parameter(m_metadataIndex[parameterIndex])->gangedProperties();
+}
