@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2022 Meltytech, LLC
+ * Copyright (c) 2014-2023 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,10 +16,16 @@
  */
 
 #include "metadatamodel.h"
+#include "controllers/filtercontroller.h"
+#include "mainwindow.h"
 #include "qmltypes/qmlmetadata.h"
 #include "settings.h"
 #include <Logger.h>
 
+#include <QGuiApplication>
+#include <QClipboard>
+#include <QSaveFile>
+
 MetadataModel::MetadataModel(QObject *parent)
     : QAbstractListModel(parent)
     , m_filter(FavoritesFilter)
@@ -28,7 +34,6 @@ MetadataModel::MetadataModel(QObject *parent)
 {
     if (Settings.playerGPU()) {
         m_filterMask |= gpuIncompatibleMaskBit;
-        m_filterMask |= gpuAlternativeMaskBit;
     } else {
         m_filterMask |= needsGPUMaskBit;
     }
@@ -159,13 +164,17 @@ bool MetadataModel::isVisible(int row) const
     if (meta->filterMask & m_filterMask) {
         return false;
     }
+    if (Settings.playerGPU() && meta->needsGPU() && MAIN.filterController()->isOutputTrackSelected()) {
+        return false;
+    }
     if (m_search.isEmpty()) {
         switch (m_filter) {
         case FavoritesFilter:
             if (!meta->isFavorite()) return false;
             break;
         case VideoFilter:
-            if (meta->isAudio() || meta->type() == QmlMetadata::Link) return false;
+            if (meta->isAudio() || meta->needsGPU() || meta->type() == QmlMetadata::Link
+                    || meta->type() == QmlMetadata::FilterSet) return false;
             break;
         case AudioFilter:
             if (!meta->isAudio()) return false;
@@ -173,6 +182,12 @@ bool MetadataModel::isVisible(int row) const
         case LinkFilter:
             if (meta->type() != QmlMetadata::Link) return false;
             break;
+        case FilterSetFilter:
+            if (meta->type() != QmlMetadata::FilterSet) return false;
+            break;
+        case GPUFilter:
+            if (!meta->needsGPU()) return false;
+            break;
         default:
             break;
         }
@@ -183,7 +198,8 @@ bool MetadataModel::isVisible(int row) const
     return true;
 }
 
-void MetadataModel::setIsClipProducer(bool isClipProducer)
+void MetadataModel::updateFilterMask(bool isClipProducer, bool isChainProducer,
+                                     bool isTrackProducer)
 {
     beginResetModel();
     m_isClipProducer = isClipProducer;
@@ -192,18 +208,18 @@ void MetadataModel::setIsClipProducer(bool isClipProducer)
     } else {
         m_filterMask |= clipOnlyMaskBit;
     }
-    endResetModel();
-}
-
-void MetadataModel::setIsChainProducer(bool isChainProducer)
-{
-    beginResetModel();
     m_isChainProducer = isChainProducer;
     if (m_isChainProducer) {
         m_filterMask &= ~linkMaskBit;
     } else {
         m_filterMask |= linkMaskBit;
     }
+    m_isTrackProducer = isTrackProducer;
+    if (m_isTrackProducer) {
+        m_filterMask &= ~trackOnlyMaskBit;
+    } else {
+        m_filterMask |= trackOnlyMaskBit;
+    }
     endResetModel();
 }
 
@@ -212,9 +228,65 @@ unsigned MetadataModel::computeFilterMask(const QmlMetadata *meta)
     unsigned mask = 0;
     if (meta->isHidden()) mask |= HiddenMaskBit;
     if (meta->isClipOnly()) mask |= clipOnlyMaskBit;
+    if (meta->isTrackOnly()) mask |= trackOnlyMaskBit;
     if (!meta->isGpuCompatible()) mask |= gpuIncompatibleMaskBit;
-    if (!meta->needsGPU() && !meta->gpuAlt().isEmpty()) mask |= gpuAlternativeMaskBit;
     if (meta->needsGPU()) mask |= needsGPUMaskBit;
     if (meta->type() == QmlMetadata::Link) mask |= linkMaskBit;
     return mask;
 }
+
+void MetadataModel::saveFilterSet(const QString &name)
+{
+    QDir dir(Settings.appDataLocation());
+    const auto folder = QString::fromLatin1("filter-sets");
+
+    if (!dir.exists())
+        dir.mkpath(dir.path());
+    if (!dir.cd(folder)) {
+        if (dir.mkdir(folder))
+            dir.cd(folder);
+    }
+
+    auto filename = QString::fromUtf8(QUrl::toPercentEncoding(name));
+    auto exists = dir.exists(filename);
+    QSaveFile file(dir.filePath(filename));
+    file.setDirectWriteFallback(true);
+    if (!file.open(QIODevice::WriteOnly | QIODevice::Truncate)) {
+        LOG_ERROR() << "failed to open filter set file for writing" << file.fileName();
+        return;
+    }
+    QTextStream stream(&file);
+    stream.setEncoding(QStringConverter::Utf8);
+    stream << QGuiApplication::clipboard()->text();
+    if (file.error() != QFileDevice::NoError) {
+        LOG_ERROR() << "error while writing filter set file" << file.fileName() << ":" <<
+                    file.errorString();
+        return;
+    }
+    if (file.commit() && !exists) {
+        auto meta = new QmlMetadata;
+        meta->setType(QmlMetadata::FilterSet);
+        meta->setName(name);
+        add(meta);
+    }
+}
+
+void MetadataModel::deleteFilterSet(const QString &name)
+{
+    QDir dir(Settings.appDataLocation());
+    if (!dir.cd("filter-sets"))
+        return;
+
+    auto fileName = QUrl::toPercentEncoding(name.toUtf8());
+    if (QFile::remove(dir.filePath(fileName)) || QFile::remove(dir.filePath(name))) {
+        auto i = 0;
+        for (const auto &meta : m_list) {
+            if (meta->type() == QmlMetadata::FilterSet && meta->name() == name) {
+                beginRemoveRows(QModelIndex(), i, i);
+                m_list.remove(i);
+                endRemoveRows();
+            }
+            ++i;
+        }
+    }
+}
