@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2021 Meltytech, LLC
+ * Copyright (c) 2012-2023 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -79,9 +79,13 @@ public:
                 service = "avformat";
             else if (service.startsWith("xml"))
                 service = "xml-nogl";
-            m_tempProducer = new Mlt::Producer(m_profile, service.toUtf8().constData(),
-                                               m_producer.get("resource"));
-            if (m_tempProducer->is_valid()) {
+            if (service == "count") {
+                m_tempProducer = new Mlt::Producer(m_profile, service.toUtf8().constData(), "loader-nogl");
+            } else if (!Settings.playerGPU() || (service != "xml-nogl" && service != "consumer")) {
+                m_tempProducer = new Mlt::Producer(m_profile, service.toUtf8().constData(),
+                                                   m_producer.get("resource"));
+            }
+            if (m_tempProducer && m_tempProducer->is_valid()) {
                 Mlt::Filter scaler(m_profile, "swscale");
                 Mlt::Filter padder(m_profile, "resize");
                 Mlt::Filter converter(m_profile, "avcolor_space");
@@ -171,6 +175,8 @@ PlaylistModel::PlaylistModel(QObject *parent)
     , m_mode(Invalid)
 {
     qRegisterMetaType<QVector<int> >("QVector<int>");
+    connect(this, &QAbstractItemModel::rowsAboutToBeRemoved, this,
+            &PlaylistModel::onRowsAboutToBeRemoved);
 }
 
 PlaylistModel::~PlaylistModel()
@@ -206,7 +212,7 @@ QVariant PlaylistModel::data(const QModelIndex &index, int role) const
 
     if (role < Qt::UserRole) {
         if (role == Qt::DisplayRole) {
-            if (m_mode == Detailed)
+            if (m_mode == Detailed || index.column() > 0)
                 field = FIELD_INDEX + index.column();
             else
                 field = FIELD_RESOURCE;
@@ -272,19 +278,19 @@ QVariant PlaylistModel::data(const QModelIndex &index, int role) const
         }
         case FIELD_IN:
             if (info->producer && info->producer->is_valid()) {
-                return info->producer->frames_to_time(info->frame_in);
+                return QString::fromLatin1(info->producer->frames_to_time(info->frame_in));
             } else {
                 return "";
             }
         case FIELD_DURATION:
             if (info->producer && info->producer->is_valid()) {
-                return info->producer->frames_to_time(info->frame_count);
+                return QString::fromLatin1(info->producer->frames_to_time(info->frame_count));
             } else {
                 return "";
             }
         case FIELD_START:
             if (info->producer && info->producer->is_valid()) {
-                return info->producer->frames_to_time(info->start);
+                return QString::fromLatin1(info->producer->frames_to_time(info->start));
             } else {
                 return "";
             }
@@ -529,7 +535,7 @@ bool PlaylistModel::dropMimeData(const QMimeData *data, Qt::DropAction action, i
     Q_UNUSED(column)
     Q_UNUSED(parent)
     // Internal reorder
-    if (action == Qt::MoveAction) {
+    if (action == Qt::MoveAction && !data->hasUrls()) {
         m_dropRow = row;
         m_rowsRemoved.clear();
         return true;
@@ -742,6 +748,15 @@ void PlaylistModel::move(int from, int to)
     emit modified();
 }
 
+void PlaylistModel::onRowsAboutToBeRemoved(const QModelIndex &parent, int first, int last)
+{
+    if (m_playlist) {
+        for (int i = first; i <= last; ++i) {
+            emit removing(m_playlist->get_clip(i));
+        }
+    }
+}
+
 void PlaylistModel::createIfNeeded()
 {
     if (!m_playlist) {
