@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2020 Meltytech, LLC
+ * Copyright (c) 2012-2023 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,9 +21,9 @@
 #include <QWidget>
 #include <QIcon>
 #include <QSize>
-#include <QTimer>
 #include "sharedframe.h"
 
+class DockToolBar;
 class ScrubBar;
 class QSpinBox;
 class QLabel;
@@ -39,10 +39,10 @@ class QHBoxLayout;
 class QPushButton;
 class TransportControllable;
 class QLabel;
-class QPropertyAnimation;
 class QPushButton;
 class QMenu;
 class NewProjectFolder;
+class StatusLabelWidget;
 
 class Player : public QWidget
 {
@@ -54,13 +54,19 @@ public:
     } TabIndex;
 
     explicit Player(QWidget *parent = 0);
-    void connectTransport(const TransportControllable*);
+    void connectTransport(const TransportControllable *);
     void setIn(int);
     void setOut(int);
-    void setMarkers(const QList<int>&);
+    void setMarkers(const QList<int> &);
     QSize videoSize() const;
-    int position() const { return m_position; }
-    NewProjectFolder* projectWidget() const { return m_projectWidget; }
+    int position() const
+    {
+        return m_position;
+    }
+    NewProjectFolder *projectWidget() const
+    {
+        return m_projectWidget;
+    }
     void moveVideoToScreen(int screen = -1);
     void setPauseAfterOpen(bool pause);
     TabIndex tabIndex() const;
@@ -85,19 +91,21 @@ signals:
     void scrolledHorizontally(int x);
     void scrolledVertically(int y);
     void tabIndexChanged(int index);
+    void trimIn();
+    void trimOut();
+    void loopChanged(int start, int end);
 
 public slots:
     void play(double speed = 1.0);
     void pause();
     void stop();
-    void togglePlayPaused();
     void seek(int position);
     void reset();
     void onProducerOpened(bool play = true);
     void postProducerOpened();
     void onMeltedUnitOpened();
     void onDurationChanged();
-    void onFrameDisplayed(const SharedFrame& frame);
+    void onFrameDisplayed(const SharedFrame &frame);
     void onVolumeChanged(int);
     void onCaptureStateChanged(bool);
     void rewind(bool forceChangeDirection = true);
@@ -107,83 +115,84 @@ public slots:
     void switchToTab(TabIndex index);
     void enableTab(TabIndex index, bool enabled = true);
     void onTabBarClicked(int index);
-    void setStatusLabel(const QString& text, int timeoutSeconds, QAction* action, QPalette::ColorRole role = QPalette::ToolTipBase);
+    void setStatusLabel(const QString &text, int timeoutSeconds, QAction *action,
+                        QPalette::ColorRole role = QPalette::ToolTipBase);
     void showIdleStatus();
     void focusPositionSpinner() const;
+    void onMuteButtonToggled(bool checked);
 
 protected:
-    void resizeEvent(QResizeEvent* event) override;
-    bool event(QEvent* event) override;
-    void keyPressEvent(QKeyEvent* event) override;
+    void resizeEvent(QResizeEvent *event) override;
+    bool event(QEvent *event) override;
+    void keyPressEvent(QKeyEvent *event) override;
 
 private:
-    void setupActions(QWidget* widget);
-    void retranslateUi(QWidget* widget);
+    void setupActions();
     void adjustScrollBars(float horizontal, float vertical);
     double setVolume(int volume);
+    void setLoopRange(int start, int end);
+    void layoutToolbars();
 
-    QAction *actionPlay;
-    QAction *actionPause;
-    QAction *actionSkipNext;
-    QAction *actionSkipPrevious;
-    QAction *actionRewind;
-    QAction *actionFastForward;
-    QAction *actionVolume;
-
-    ScrubBar* m_scrubber;
-    TimeSpinBox* m_positionSpinner;
-    QLabel* m_durationLabel;
-    QLabel* m_inPointLabel;
-    QLabel* m_selectedLabel;
+    ScrubBar *m_scrubber;
+    TimeSpinBox *m_positionSpinner;
+    QLabel *m_durationLabel;
+    QLabel *m_inPointLabel;
+    QLabel *m_selectedLabel;
     int m_position;
     int m_playPosition;
     QIcon m_playIcon;
+    QIcon m_loopIcon;
     QIcon m_pauseIcon;
-    QFrame* m_volumePopup;
-    QSlider* m_volumeSlider;
-    QWidget* m_volumeWidget;
-    QPushButton* m_muteButton;
+    QIcon m_stopIcon;
+    QFrame *m_volumePopup;
+    QSlider *m_volumeSlider;
+    QPushButton *m_muteButton;
     int m_previousIn;
     int m_previousOut;
     double m_savedVolume;
     int m_duration;
     bool m_isSeekable;
     int m_isMeltedPlaying;
-    QScrollBar* m_horizontalScroll;
-    QScrollBar* m_verticalScroll;
-    QToolButton* m_zoomButton;
-    QToolButton* m_gridButton;
-    QActionGroup* m_gridActionGroup;
-    QAction* m_gridDefaultAction;
+    QScrollBar *m_horizontalScroll;
+    QScrollBar *m_verticalScroll;
+    QToolButton *m_zoomButton;
+    QToolButton *m_gridButton;
+    QActionGroup *m_gridActionGroup;
+    QAction *m_gridDefaultAction;
+    QToolButton *m_volumeButton;
     float m_zoomToggleFactor;
-    QTabBar* m_tabs;
+    QTabBar *m_tabs;
     bool m_pauseAfterOpen;
     int m_monitorScreen;
-    QWidget* m_videoWidget;
-    QHBoxLayout* m_videoLayout;
-    QWidget* m_videoScrollWidget;
-    const TransportControllable* m_currentTransport;
-    QPushButton * m_statusLabel;
-    QPropertyAnimation* m_statusFadeIn;
-    QPropertyAnimation* m_statusFadeOut;
-    QTimer m_statusTimer;
-    QMenu* m_zoomMenu;
-    NewProjectFolder* m_projectWidget;
+    QWidget *m_videoWidget;
+    QHBoxLayout *m_videoLayout;
+    QWidget *m_videoScrollWidget;
+    const TransportControllable *m_currentTransport;
+    StatusLabelWidget *m_statusLabel;
+    QMenu *m_zoomMenu;
+    QMenu *m_mainMenu;
+    NewProjectFolder *m_projectWidget;
+    int m_loopStart;
+    int m_loopEnd;
+    DockToolBar *m_currentDurationToolBar;
+    DockToolBar *m_controlsToolBar;
+    DockToolBar *m_optionsToolBar;
+    DockToolBar *m_inSelectedToolBar;
+    QHBoxLayout *m_toolRow1;
+    QHBoxLayout *m_toolRow2;
 
 private slots:
     void updateSelection();
     void onInChanged(int in);
     void onOutChanged(int out);
-    void on_actionSkipNext_triggered();
-    void on_actionSkipPrevious_triggered();
-    void on_actionVolume_triggered();
-    void onMuteButtonToggled(bool checked);
+    void onVolumeTriggered();
     void setZoom(float factor, const QIcon &icon);
     void onZoomTriggered();
     void toggleZoom(bool checked);
     void onGridToggled();
     void toggleGrid(bool checked);
-    void onFadeOutFinished();
+    void onStatusFinished();
+    void onOffsetChanged(const QPoint &offset);
 };
 
 #endif // PLAYER_H
