@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2020-2022 Meltytech, LLC
+ * Copyright (c) 2020-2024 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -170,7 +170,8 @@ void ProxyManager::generateVideoProxy(Mlt::Producer &producer, bool fullRange, S
         if (hwCodecs.contains("hevc_nvenc")) {
             args << "-codec:v" << "hevc_nvenc";
             args << "-rc" << "constqp";
-            args << "-vglobal_quality" << "37";
+            args << "-qp:v" << "37";
+            args << "-b_ref_mode" << "0";
         } else if (hwCodecs.contains("hevc_qsv")) {
             args << "-load_plugin" << "hevc_hw";
             args << "-codec:v" << "hevc_qsv";
@@ -186,17 +187,27 @@ void ProxyManager::generateVideoProxy(Mlt::Producer &producer, bool fullRange, S
         } else if (hwCodecs.contains("h264_nvenc")) {
             args << "-codec:v" << "h264_nvenc";
             args << "-rc" << "constqp";
-            args << "-vglobal_quality" << "37";
+            args << "-qp:v" << "37";
+            args << "-b_ref_mode" << "0";
         } else if (hwCodecs.contains("h264_vaapi")) {
             args << "-init_hw_device" << "vaapi=vaapi0:" << "-filter_hw_device" << "vaapi0";
             args << "-codec:v" << "h264_vaapi";
             args << "-qp" << "30";
+#if (defined(Q_OS_MAC) && defined(Q_PROCESSOR_ARM))
+        } else if (!fullRange && hwCodecs.contains("hevc_videotoolbox")) {
+            args << "-codec:v" << "hevc_videotoolbox";
+            args << "-q:v" << "45";
+        } else if (!fullRange && hwCodecs.contains("h264_videotoolbox")) {
+            args << "-codec:v" << "h264_videotoolbox";
+            args << "-q:v" << "45";
+#else
         } else if (hwCodecs.contains("hevc_videotoolbox")) {
             args << "-codec:v" << "hevc_videotoolbox";
-            args << "-b:v" << "2M";
+            args << "-b:v" << "5M";
         } else if (hwCodecs.contains("h264_videotoolbox")) {
             args << "-codec:v" << "h264_videotoolbox";
-            args << "-b:v" << "2M";
+            args << "-b:v" << "8M";
+#endif
         } else if (hwCodecs.contains("h264_qsv")) {
             args << "-codec:v" << "h264_qsv";
             args << "-q:v" << "36";
@@ -211,7 +222,9 @@ void ProxyManager::generateVideoProxy(Mlt::Producer &producer, bool fullRange, S
         args << "-preset" << "veryfast";
         args << "-crf" << "23";
     }
-    args << "-g" << "1" << "-bf" << "0";
+    args << "-g" << QString::fromLatin1(hwCodecs.contains("hevc_nvenc") ? "0" :
+                                        hwCodecs.contains("h264_nvenc") ? "2" : "1");
+    args << "-bf" << "0";
     args << "-y" << fileName;
 
     FfmpegJob *job = new FfmpegJob(fileName, args, true);
@@ -228,10 +241,8 @@ void ProxyManager::generateImageProxy(Mlt::Producer &producer, bool replace)
 {
     // Always regenerate per preview scaling or 540 if not specified
     QString resource = ProxyManager::resource(producer);
-    QStringList args;
     QString hash = Util::getHash(producer);
     QString fileName = ProxyManager::dir().filePath(hash + kProxyPendingImageExtension);
-    QString filters;
 
     // Touch file to make it in progress
     QFile file(fileName);
@@ -283,14 +294,14 @@ static void processProperties(QXmlStreamWriter &newXml, QVector<MltProperty> &pr
                     newResource = newResource.mid(root.size());
                 }
                 if (service == "timewarp") {
-                    newProperties << MltProperty(p.first, QString("%1:%2").arg(speed).arg(newResource));
+                    newProperties << MltProperty(p.first, QString("%1:%2").arg(speed, newResource));
                 } else {
                     newProperties << MltProperty(p.first, newResource);
                 }
             } else if (p.first == "warp_resource") {
                 newProperties << MltProperty(p.first, newResource);
-                // Remove special proxy and original resource properties
             } else if (p.first != kIsProxyProperty && p.first != kOriginalResourceProperty) {
+                // Remove special proxy and original resource properties
                 newProperties << MltProperty(p.first, p.second);
             }
         }
@@ -370,7 +381,7 @@ bool ProxyManager::filterXML(QString &xmlString, QString root)
         }
         case QXmlStreamReader::EndElement:
             // At the end of a non-property element
-            if (xml.name() != "property") {
+            if (xml.name().toString() != "property") {
                 processProperties(newXml, properties, root);
                 newXml.writeEndElement();
             }
@@ -480,6 +491,7 @@ bool ProxyManager::generateIfNotExists(Mlt::Producer &producer, bool replace)
                 auto gopro = GoProProxyFilePath(producer.get("resource"));
                 if (QFile::exists(gopro)) {
                     producer.set(kIsProxyProperty, 1);
+                    producer.set(kMetaProxyProperty, 1);
                     producer.set(kOriginalResourceProperty, producer.get("resource"));
                     producer.set("resource", gopro.toUtf8().constData());
                     return true;
@@ -492,6 +504,7 @@ bool ProxyManager::generateIfNotExists(Mlt::Producer &producer, bool replace)
                 return false;
             }
             producer.set(kIsProxyProperty, 1);
+            producer.set(kMetaProxyProperty, 1);
             producer.set(kOriginalResourceProperty, producer.get("resource"));
             if (projectDir.exists(fileName)) {
                 ::utime(projectDir.filePath(fileName).toUtf8().constData(), nullptr);
