@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2022 Meltytech, LLC
+ * Copyright (c) 2016-2023 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +20,10 @@
 #include "util.h"
 #include "models/audiolevelstask.h"
 #include "mainwindow.h"
+#include "qmltypes/qmlapplication.h"
 #include "widgets/glaxnimateproducerwidget.h"
+#include "settings.h"
+#include <Logger.h>
 
 static const char *kWidthProperty = "meta.media.width";
 static const char *kHeightProperty = "meta.media.height";
@@ -169,7 +172,7 @@ void QmlProducer::launchGlaxnimate(const QString &filename) const
     }
 }
 
-void QmlProducer::audioLevelsReady(const QModelIndex &index)
+void QmlProducer::audioLevelsReady(const QPersistentModelIndex &index)
 {
     Q_UNUSED(index)
     emit audioLevelsChanged();
