@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011-2022 Meltytech, LLC
+ * Copyright (c) 2011-2023 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -37,6 +37,8 @@ ScrubBar::ScrubBar(QWidget *parent)
     , m_margin(14) /// left and right margins
     , m_activeControl(CONTROL_NONE)
     , m_timecodeWidth(0)
+    , m_loopStart(-1)
+    , m_loopEnd(-1)
 {
     setMouseTracking(true);
     setMinimumHeight(fontMetrics().height() + selectionSize);
@@ -106,9 +108,16 @@ void ScrubBar::setMarkers(const QList<int> &list)
     updatePixmap();
 }
 
+void ScrubBar::setLoopRange(int start, int end)
+{
+    m_loopStart = start;
+    m_loopEnd = end;
+    updatePixmap();
+}
+
 void ScrubBar::mousePressEvent(QMouseEvent *event)
 {
-    int x = event->x() - m_margin;
+    int x = event->position().x() - m_margin;
     int in = m_in * m_scale;
     int out = m_out * m_scale;
     int head = m_head * m_scale;
@@ -144,7 +153,7 @@ void ScrubBar::mouseReleaseEvent(QMouseEvent *event)
 
 void ScrubBar::mouseMoveEvent(QMouseEvent *event)
 {
-    int x = event->x() - m_margin;
+    int x = event->position().x() - m_margin;
     int pos = CLAMP(x / m_scale, 0, m_max);
 
     if (event->buttons() & Qt::LeftButton) {
@@ -163,7 +172,7 @@ void ScrubBar::mouseMoveEvent(QMouseEvent *event)
         emit seeked(pos);
     } else if (event->buttons() == Qt::NoButton && MLT.producer()) {
         QString text = QString::fromLatin1(MLT.producer()->frames_to_time(pos));
-        QToolTip::showText(event->globalPos(), text);
+        QToolTip::showText(event->globalPosition().toPoint(), text);
     }
 }
 
@@ -318,6 +327,15 @@ void ScrubBar::updatePixmap()
         }
     }
 
+    // draw loop range
+    if (m_loopStart > -1 && m_loopEnd > -1) {
+        const int start = m_loopStart * m_scale * ratio;
+        const int end = m_loopEnd * m_scale * ratio;
+        QColor loopColor = palette().highlight().color();
+        loopColor.setAlphaF(0.5);
+        p.fillRect(l_margin + start, l_height - 7 * ratio, end - start, l_height * ratio, loopColor);
+    }
+
     p.end();
     update();
 }
