@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013-2022 Meltytech, LLC
+ * Copyright (c) 2013-2024 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,14 +22,17 @@
 #include <QStandardPaths>
 #include <QFile>
 #include <QDir>
-#include <QAudioDeviceInfo>
+#include <QMediaDevices>
+#include <QAudioDevice>
 #include <Logger.h>
 
 static const QString APP_DATA_DIR_KEY("appdatadir");
 static const QString SHOTCUT_INI_FILENAME("/shotcut.ini");
+static const QString RECENT_INI_FILENAME("recent.ini");
 static QScopedPointer<ShotcutSettings> instance;
 static QString appDataForSession;
 static const int kMaximumTrackHeight = 125;
+static const QString kRecentKey("recent");
 
 ShotcutSettings &ShotcutSettings::singleton()
 {
@@ -46,25 +49,73 @@ ShotcutSettings &ShotcutSettings::singleton()
     return *instance;
 }
 
+ShotcutSettings::ShotcutSettings()
+    : QObject()
+    , m_recent(QDir(appDataLocation()).filePath(RECENT_INI_FILENAME), QSettings::IniFormat)
+{
+    migrateLayout();
+    migrateRecent();
+}
+
 ShotcutSettings::ShotcutSettings(const QString &appDataLocation)
     : QObject()
     , settings(appDataLocation + SHOTCUT_INI_FILENAME, QSettings::IniFormat)
     , m_appDataLocation(appDataLocation)
+    , m_recent(QDir(appDataLocation).filePath(RECENT_INI_FILENAME), QSettings::IniFormat)
 {
+    migrateLayout();
+    migrateRecent();
+}
+
+void ShotcutSettings::migrateRecent()
+{
+    // Migrate recent to separate INI file
+    auto oldRecents = settings.value(kRecentKey).toStringList();
+    if (recent().isEmpty() && !oldRecents.isEmpty()) {
+        auto newRecents = recent();
+        for (const auto &a : oldRecents) {
+            if (a.size() < ShotcutSettings::MaxPath && !newRecents.contains(a)) {
+                while (newRecents.size() > 100) {
+                    newRecents.removeFirst();
+                }
+                newRecents.append(a);
+            }
+        }
+        setRecent(newRecents);
+        m_recent.sync();
+//        settings.remove("recent");
+        settings.sync();
+    }
+}
+
+void ShotcutSettings::migrateLayout()
+{
+    // Migrate old startup layout to a custom layout and start fresh
+    if (!settings.contains("geometry2")) {
+        auto geometry = settings.value("geometry").toByteArray();
+        auto windowState = settings.value("windowState").toByteArray();
+        setLayout(tr("Old (before v23) Layout"), geometry, windowState);
+        setLayoutMode(2);
+        settings.sync();
+    }
 }
 
 void ShotcutSettings::log()
 {
-    LOG_DEBUG() << "language" << language();
-    LOG_DEBUG() << "deinterlacer" << playerDeinterlacer();
-    LOG_DEBUG() << "external monitor" << playerExternal();
-    LOG_DEBUG() << "GPU processing" << playerGPU();
-    LOG_DEBUG() << "interpolation" << playerInterpolation();
-    LOG_DEBUG() << "video mode" << playerProfile();
-    LOG_DEBUG() << "realtime" << playerRealtime();
-    LOG_DEBUG() << "audio channels" << playerAudioChannels();
-#ifdef Q_OS_WIN
-    LOG_DEBUG() << "display method" << drawMethod();
+    LOG_INFO() << "language" << language();
+    LOG_INFO() << "deinterlacer" << playerDeinterlacer();
+    LOG_INFO() << "external monitor" << playerExternal();
+    LOG_INFO() << "GPU processing" << playerGPU();
+    LOG_INFO() << "interpolation" << playerInterpolation();
+    LOG_INFO() << "video mode" << playerProfile();
+    LOG_INFO() << "realtime" << playerRealtime();
+    LOG_INFO() << "audio channels" << playerAudioChannels();
+#if defined(Q_OS_WIN) || defined(Q_OS_LINUX)
+    if (::qEnvironmentVariableIsSet("SDL_AUDIODRIVER")) {
+        LOG_INFO() << "audio driver" <<::qgetenv("SDL_AUDIODRIVER");
+    } else {
+        LOG_INFO() << "audio driver" << playerAudioDriver();
+    }
 #endif
 }
 
@@ -117,15 +168,15 @@ void ShotcutSettings::setSavePath(const QString &s)
 
 QStringList ShotcutSettings::recent() const
 {
-    return settings.value("recent").toStringList();
+    return m_recent.value(kRecentKey).toStringList();
 }
 
 void ShotcutSettings::setRecent(const QStringList &ls)
 {
     if (ls.isEmpty())
-        settings.remove("recent");
+        m_recent.remove(kRecentKey);
     else if (!clearRecent())
-        settings.setValue("recent", ls);
+        m_recent.setValue(kRecentKey, ls);
 }
 
 QString ShotcutSettings::theme() const
@@ -195,12 +246,12 @@ void ShotcutSettings::setSmallIcons(bool b)
 
 QByteArray ShotcutSettings::windowGeometry() const
 {
-    return settings.value("geometry").toByteArray();
+    return settings.value("geometry2").toByteArray();
 }
 
 void ShotcutSettings::setWindowGeometry(const QByteArray &a)
 {
-    settings.setValue("geometry", a);
+    settings.setValue("geometry2", a);
 }
 
 QByteArray ShotcutSettings::windowGeometryDefault() const
@@ -215,12 +266,12 @@ void ShotcutSettings::setWindowGeometryDefault(const QByteArray &a)
 
 QByteArray ShotcutSettings::windowState() const
 {
-    return settings.value("windowState").toByteArray();
+    return settings.value("windowState2").toByteArray();
 }
 
 void ShotcutSettings::setWindowState(const QByteArray &a)
 {
-    settings.setValue("windowState", a);
+    settings.setValue("windowState2", a);
 }
 
 QByteArray ShotcutSettings::windowStateDefault() const
@@ -375,19 +426,9 @@ void ShotcutSettings::setPlayerExternal(const QString &s)
     settings.setValue("player/external", s);
 }
 
-QString ShotcutSettings::playerGamma() const
-{
-    return settings.value("player/gamma", "bt709").toString();
-}
-
-void ShotcutSettings::setPlayerGamma(const QString &s)
-{
-    settings.setValue("player/gamma", s);
-}
-
 void ShotcutSettings::setPlayerGPU(bool b)
 {
-    settings.setValue("player/gpu", b);
+    settings.setValue("player/gpu2", b);
     emit playerGpuChanged();
 }
 
@@ -408,12 +449,12 @@ void ShotcutSettings::setPlayerInterpolation(const QString &s)
 
 bool ShotcutSettings::playerGPU() const
 {
-    return settings.value("player/gpu", false).toBool();
+    return settings.value("player/gpu2", false).toBool();
 }
 
 bool ShotcutSettings::playerWarnGPU() const
 {
-    return settings.value("player/warnGPU", false).toBool();
+    return false; //settings.value("player/warnGPU", false).toBool();
 }
 
 void ShotcutSettings::setPlayerJACK(bool b)
@@ -531,6 +572,25 @@ void ShotcutSettings::setPlayerJumpSeconds(double i)
     settings.setValue("player/jumpSeconds", i);
 }
 
+QString ShotcutSettings::playerAudioDriver() const
+{
+#if defined(Q_OS_WIN)
+    auto s = playerAudioChannels() > 2 ? "directsound" : "winmm";
+#else
+    auto s = "pulseaudio";
+#endif
+    if (::qEnvironmentVariableIsSet("SDL_AUDIODRIVER")) {
+        return ::qgetenv("SDL_AUDIODRIVER");
+    } else {
+        return settings.value("player/audioDriver", s).toString();
+    }
+}
+
+void ShotcutSettings::setPlayerAudioDriver(const QString &s)
+{
+    settings.setValue("player/audioDriver", s);
+}
+
 QString ShotcutSettings::playlistThumbnails() const
 {
     return settings.value("playlist/thumbnails", "small").toString();
@@ -629,17 +689,6 @@ void ShotcutSettings::setTimelineSnap(bool b)
     emit timelineSnapChanged();
 }
 
-bool ShotcutSettings::timelineCenterPlayhead() const
-{
-    return settings.value("timeline/centerPlayhead", false).toBool();
-}
-
-void ShotcutSettings::setTimelineCenterPlayhead(bool b)
-{
-    settings.setValue("timeline/centerPlayhead", b);
-    emit timelineCenterPlayheadChanged();
-}
-
 int ShotcutSettings::timelineTrackHeight() const
 {
     return qMin(settings.value("timeline/trackHeight", 50).toInt(), kMaximumTrackHeight);
@@ -700,6 +749,45 @@ void ShotcutSettings::setTimelinePreviewTransition(bool b)
     settings.setValue("timeline/previewTransition", b);
 }
 
+void ShotcutSettings::setTimelineScrolling(ShotcutSettings::TimelineScrolling value)
+{
+    settings.remove("timeline/centerPlayhead");
+    settings.setValue("timeline/scrolling", value);
+    emit timelineScrollingChanged();
+}
+
+ShotcutSettings::TimelineScrolling ShotcutSettings::timelineScrolling() const
+{
+    if (settings.contains("timeline/centerPlayhead")
+            && settings.value("timeline/centerPlayhead").toBool())
+        return ShotcutSettings::TimelineScrolling::CenterPlayhead;
+    else
+        return ShotcutSettings::TimelineScrolling(settings.value("timeline/scrolling",
+                                                                 PageScrolling).toInt());
+}
+
+bool ShotcutSettings::timelineAutoAddTracks() const
+{
+    return settings.value("timeline/autoAddTracks", false).toBool();
+}
+
+void ShotcutSettings::setTimelineAutoAddTracks(bool b)
+{
+    settings.setValue("timeline/autoAddTracks", b);
+    emit timelineAutoAddTracksChanged();
+}
+
+bool ShotcutSettings::timelineRectangleSelect() const
+{
+    return settings.value("timeline/rectangleSelect", true).toBool();
+}
+
+void ShotcutSettings::setTimelineRectangleSelect(bool b)
+{
+    settings.setValue("timeline/rectangleSelect", b);
+    emit timelineRectangleSelectChanged();
+}
+
 QString ShotcutSettings::filterFavorite(const QString &filterName)
 {
     return settings.value("filter/favorite/" + filterName, "").toString();
@@ -910,14 +998,14 @@ bool ShotcutSettings::setLayout(const QString &name, const QByteArray &geometry,
                                 const QByteArray &state)
 {
     bool isNew = false;
-    QStringList layouts = Settings.layouts();
+    QStringList layouts = this->layouts();
     if (layouts.indexOf(name) == -1) {
         isNew = true;
         layouts.append(name);
         settings.setValue("layout/layouts", layouts);
     }
-    settings.setValue(QString("layout/%1_%2").arg(name).arg("geometry"), geometry);
-    settings.setValue(QString("layout/%1_%2").arg(name).arg("state"), state);
+    settings.setValue(QString("layout/%1_%2").arg(name, "geometry"), geometry);
+    settings.setValue(QString("layout/%1_%2").arg(name, "state"), state);
     return isNew;
 }
 
@@ -943,8 +1031,8 @@ bool ShotcutSettings::removeLayout(const QString &name)
             settings.remove("layout/layouts");
         else
             settings.setValue("layout/layouts", list);
-        settings.remove(QString("layout/%1_%2").arg(name).arg("geometry"));
-        settings.remove(QString("layout/%1_%2").arg(name).arg("state"));
+        settings.remove(QString("layout/%1_%2").arg(name, "geometry"));
+        settings.remove(QString("layout/%1_%2").arg(name, "state"));
         return true;
     }
     return false;
@@ -985,8 +1073,8 @@ QString ShotcutSettings::audioInput() const
 {
     QString defaultValue  = "default";
 #if defined(Q_OS_MAC) || defined(Q_OS_WIN)
-    for (const auto &deviceInfo : QAudioDeviceInfo::availableDevices(QAudio::AudioInput)) {
-        defaultValue = deviceInfo.deviceName();
+    for (const auto &deviceInfo : QMediaDevices::audioInputs()) {
+        defaultValue = deviceInfo.description();
     }
 #endif
     return settings.value("audioInput", defaultValue).toString();
@@ -1104,6 +1192,66 @@ QList<QKeySequence> ShotcutSettings::shortcuts(const QString &name)
     return shortcuts;
 }
 
+double ShotcutSettings::slideshowClipDuration(double defaultClipDuration) const
+{
+    return settings.value("slideshow/clipDuration", defaultClipDuration).toDouble();
+}
+
+void ShotcutSettings::setSlideshowClipDuration(double clipDuration)
+{
+    settings.setValue("slideshow/clipDuration", clipDuration);
+}
+
+int ShotcutSettings::slideshowAspectConversion(int defaultAspectConversion) const
+{
+    return settings.value("slideshow/aspectConversion", defaultAspectConversion).toInt();
+}
+
+void ShotcutSettings::setSlideshowAspectConversion(int aspectConversion)
+{
+    settings.setValue("slideshow/aspectConversion", aspectConversion);
+}
+
+int ShotcutSettings::slideshowZoomPercent(int defaultZoomPercent) const
+{
+    return settings.value("slideshow/zoomPercent", defaultZoomPercent).toInt();
+}
+
+void ShotcutSettings::setSlideshowZoomPercent(int zoomPercent)
+{
+    settings.setValue("slideshow/zoomPercent", zoomPercent);
+}
+
+double ShotcutSettings::slideshowTransitionDuration(double defaultTransitionDuration) const
+{
+    return settings.value("slideshow/transitionDuration", defaultTransitionDuration).toDouble();
+}
+
+void ShotcutSettings::setSlideshowTransitionDuration(double transitionDuration)
+{
+    settings.setValue("slideshow/transitionDuration", transitionDuration);
+}
+
+int ShotcutSettings::slideshowTransitionStyle(int defaultTransitionStyle) const
+{
+    return settings.value("slideshow/transitionStyle", defaultTransitionStyle).toInt();
+}
+
+void ShotcutSettings::setSlideshowTransitionStyle(int transitionStyle)
+{
+    settings.setValue("slideshow/transitionStyle", transitionStyle);
+}
+
+int ShotcutSettings::slideshowTransitionSoftness(int defaultTransitionStyle) const
+{
+    return settings.value("slideshow/transitionSoftness", defaultTransitionStyle).toInt();
+}
+
+void ShotcutSettings::setSlideshowTransitionSoftness(int transitionSoftness)
+{
+    settings.setValue("slideshow/transitionSoftness", transitionSoftness);
+}
+
 void ShotcutSettings::reset()
 {
     for (auto &key : settings.allKeys()) {
@@ -1113,5 +1261,20 @@ void ShotcutSettings::reset()
 
 int ShotcutSettings::undoLimit() const
 {
-    return settings.value("undoLimit", 1000).toInt();
+    return settings.value("undoLimit", 50).toInt();
+}
+
+bool ShotcutSettings::warnLowMemory() const
+{
+    return settings.value("warnLowMemory", true).toBool();
+}
+
+int ShotcutSettings::backupPeriod() const
+{
+    return settings.value("backupPeriod", 24 * 60).toInt();
+}
+
+void ShotcutSettings::setBackupPeriod(int seconds)
+{
+    settings.setValue("backupPeriod", seconds);
 }
