@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2022 Meltytech, LLC
+ * Copyright (c) 2014-2023 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,7 +32,11 @@
 #include <QApplication>
 #include <QCryptographicHash>
 #include <QtGlobal>
-#include <QCameraInfo>
+#include <QMediaDevices>
+#include <QCamera>
+#include <QCameraDevice>
+#include <QStorageInfo>
+#include <QCheckBox>
 
 #include <MltChain.h>
 #include <MltProducer.h>
@@ -41,6 +45,8 @@
 #include "shotcut_mlt_properties.h"
 #include "qmltypes/qmlapplication.h"
 #include "proxymanager.h"
+#include "settings.h"
+
 #include <math.h>
 #include <memory>
 
@@ -53,12 +59,13 @@ static const unsigned int kLowMemoryThresholdPercent = 10U;
 #else
 static const unsigned int kLowMemoryThresholdKB = 256U * 1024U;
 #endif
+static const qint64 kFreeSpaceThesholdGB = 25LL * 1024 * 1024 * 1024;
 
 QString Util::baseName(const QString &filePath, bool trimQuery)
 {
     QString s = filePath;
     // Only if absolute path and not a URI.
-    if (s.startsWith('/') || s.midRef(1, 2) == ":/" || s.midRef(1, 2) == ":\\")
+    if (s.startsWith('/') || s.mid(1, 2) == ":/" || s.mid(1, 2) == ":\\")
         s = QFileInfo(s).fileName();
     if (trimQuery) {
         return removeQueryString(s);
@@ -268,7 +275,7 @@ bool Util::isDecimalPoint(QChar ch)
 bool Util::isNumeric(QString &str)
 {
     for (int i = 0; i < str.size(); ++i) {
-        QCharRef ch = str[i];
+        auto ch = str[i];
         if (ch != '+' && ch != '-' && ch.toLower() != 'e'
                 && !isDecimalPoint(ch) && !ch.isDigit())
             return false;
@@ -282,7 +289,7 @@ bool Util::convertNumericString(QString &str, QChar decimalPoint)
     bool result = false;
     if (isNumeric(str)) {
         for (int i = 0; i < str.size(); ++i) {
-            QCharRef ch = str[i];
+            auto ch = str[i];
             if (ch != decimalPoint && isDecimalPoint(ch)) {
                 ch = decimalPoint;
                 result = true;
@@ -298,7 +305,7 @@ bool Util::convertDecimalPoints(QString &str, QChar decimalPoint)
     bool result = false;
     if (!str.contains(decimalPoint)) {
         for (int i = 0; i < str.size(); ++i) {
-            QCharRef ch = str[i];
+            auto ch = str[i];
             // Space is used as a delimiter for rect fields and possibly elsewhere.
             if (ch != decimalPoint && ch != ' ' && isDecimalPoint(ch)) {
                 ch = decimalPoint;
@@ -337,13 +344,13 @@ QTemporaryFile *Util::writableTemporaryFile(const QString &filePath, const QStri
 
     // First, try the system temp dir.
     QString templateFilePath = QDir(QDir::tempPath()).filePath(templateFileName);
-    QScopedPointer<QTemporaryFile> tmp(new QTemporaryFile(templateFilePath));
+    std::unique_ptr<QTemporaryFile> tmp(new QTemporaryFile(templateFilePath));
 
     if (!tmp->open() || tmp->write("") < 0) {
         // Otherwise, use the directory provided.
         return new QTemporaryFile(info.dir().filePath(templateFileName));
     } else {
-        return tmp.take();
+        return tmp.release();
     }
 }
 
@@ -368,7 +375,8 @@ void Util::applyCustomProperties(Mlt::Producer &destination, Mlt::Producer &sour
     p.clear(kOriginalOutProperty);
     if (!p.get_int(kIsProxyProperty))
         p.clear(kOriginalResourceProperty);
-    destination.pass_list(source, "mlt_service, audio_index, video_index, force_progressive, force_tff,"
+    destination.pass_list(source,
+                          "mlt_service, audio_index, video_index, astream, vstream, force_progressive, force_tff,"
                           "force_aspect_ratio, video_delay, color_range, warp_speed, warp_pitch, rotate,"
                           kAspectRatioNumerator ","
                           kAspectRatioDenominator ","
@@ -450,14 +458,14 @@ QString Util::getHash(Mlt::Properties &properties)
 
 bool Util::hasDriveLetter(const QString &path)
 {
-    auto driveSeparators = path.midRef(1, 2);
+    auto driveSeparators = path.mid(1, 2);
     return driveSeparators == ":/" || driveSeparators == ":\\";
 }
 
 QFileDialog::Options Util::getFileDialogOptions()
 {
 #if defined(Q_OS_UNIX) && !defined(Q_OS_MAC)
-    if (qEnvironmentVariableIsSet("SNAP")) {
+    if (qEnvironmentVariableIsSet("SNAP") || qEnvironmentVariableIsSet("GNOME_SHELL_SESSION_MODE")) {
         return QFileDialog::DontUseNativeDialog;
     }
 #endif
@@ -587,39 +595,36 @@ QString Util::textColor(const QColor &color)
 
 void Util::cameraFrameRateSize(const QByteArray &deviceName, qreal &frameRate, QSize &size)
 {
-    std::unique_ptr<QCamera> camera(new QCamera(deviceName));
+    std::unique_ptr<QCamera> camera;
+    for (const QCameraDevice &cameraDevice : QMediaDevices::videoInputs()) {
+        if (cameraDevice.id() == deviceName) {
+            camera.reset(new QCamera(cameraDevice));
+            break;
+        }
+    }
     if (camera) {
-        camera->load();
-        QCameraViewfinderSettings viewfinderSettings;
-        auto resolutions = camera->supportedViewfinderResolutions(viewfinderSettings);
+        auto currentFormat = camera->cameraDevice().videoFormats().first();
+        QList<QSize> resolutions;
+        for (const auto &format : camera->cameraDevice().videoFormats()) {
+            resolutions << format.resolution();
+        }
         if (resolutions.size() > 0) {
             LOG_INFO() << "resolutions:" << resolutions;
             // Get the highest resolution
-            viewfinderSettings.setResolution(resolutions.first());
-            for (auto &resolution : resolutions) {
-                if (resolution.width() > viewfinderSettings.resolution().width()
-                        && resolution.height() > viewfinderSettings.resolution().height()) {
-                    viewfinderSettings.setResolution(resolution);
-                }
-            }
-            auto frameRates = camera->supportedViewfinderFrameRateRanges(viewfinderSettings);
-            if (frameRates.size() > 0) {
-                // Get the highest frame rate for the chosen resolution
-                viewfinderSettings.setMaximumFrameRate(frameRates.first().maximumFrameRate);
-                for (auto &frameRate : frameRates) {
-                    LOG_INFO() << "frame rate:" << frameRate.maximumFrameRate;
-                    if (frameRate.maximumFrameRate > viewfinderSettings.maximumFrameRate()) {
-                        viewfinderSettings.setMaximumFrameRate(frameRate.maximumFrameRate);
-                    }
+            camera->setCameraFormat(currentFormat);
+            for (const auto &format : camera->cameraDevice().videoFormats()) {
+                if (format.resolution().width() > currentFormat.resolution().width()
+                        && format.resolution().height() > currentFormat.resolution().height()) {
+                    camera->setCameraFormat(format);
+                    currentFormat = format;
                 }
             }
         }
-        camera->unload();
-        if (viewfinderSettings.maximumFrameRate() > 0) {
-            frameRate = viewfinderSettings.maximumFrameRate();
+        if (currentFormat.maxFrameRate() > 0) {
+            frameRate = currentFormat.maxFrameRate();
         }
-        if (viewfinderSettings.resolution().width() > 0) {
-            size = viewfinderSettings.resolution();
+        if (currentFormat.resolution().width() > 0) {
+            size = currentFormat.resolution();
         }
     }
 }
@@ -681,7 +686,7 @@ QString Util::updateCaption(Mlt::Producer *producer)
 
 void Util::passProducerProperties(Mlt::Producer *src, Mlt::Producer *dst)
 {
-    dst->pass_list(*src, "audio_index, video_index, force_aspect_ratio,"
+    dst->pass_list(*src, "audio_index, video_index, astream, vstream, force_aspect_ratio,"
                    "video_delay, force_progressive, force_tff, force_full_range, color_range, warp_pitch, rotate,"
                    kAspectRatioNumerator ","
                    kAspectRatioDenominator ","
@@ -700,3 +705,131 @@ void Util::passProducerProperties(Mlt::Producer *src, Mlt::Producer *dst)
     if (service.startsWith("avformat") || shotcutProducer == "avformat")
         dst->set(kShotcutProducerProperty, "avformat");
 }
+
+bool Util::warnIfLowDiskSpace(const QString &path)
+{
+    // Check if the drive this file will be on is getting low on space.
+    if (Settings.encodeFreeSpaceCheck()) {
+        QStorageInfo si(QFileInfo(path).path());
+        LOG_DEBUG() << si.bytesAvailable() << "bytes available on" << si.displayName();
+        if (si.isValid() && si.bytesAvailable() < kFreeSpaceThesholdGB) {
+            QMessageBox dialog(QMessageBox::Question, QApplication::applicationDisplayName(),
+                               QObject::tr("The drive you chose only has %1 MiB of free space.\n"
+                                           "Do you still want to continue?")
+                               .arg(si.bytesAvailable() / 1024 / 1024),
+                               QMessageBox::No | QMessageBox::Yes);
+            dialog.setWindowModality(QmlApplication::dialogModality());
+            dialog.setDefaultButton(QMessageBox::Yes);
+            dialog.setEscapeButton(QMessageBox::No);
+            dialog.setCheckBox(new QCheckBox(QObject::tr("Do not show this anymore.",
+                                                         "Export free disk space warning dialog")));
+            int result = dialog.exec();
+            if (dialog.checkBox()->isChecked())
+                Settings.setEncodeFreeSpaceCheck(false);
+            if (result == QMessageBox::No) {
+                return true;
+            }
+        }
+    }
+    return false;
+}
+
+bool Util::isFpsDifferent(double a, double b)
+{
+    return qAbs(a - b) > 0.001;
+}
+
+QString Util::getNextFile(const QString &filePath)
+{
+    QFileInfo info(filePath);
+    QString basename = info.completeBaseName();
+    QString extension = info.suffix();
+    if (extension.isEmpty()) {
+        extension = basename;
+        basename = QString();
+    }
+    for (unsigned i = 1; i < std::numeric_limits<unsigned>::max(); i++) {
+        QString filename = QString::fromLatin1("%1%2.%3").arg(basename).arg(i).arg(extension);
+        if (!info.dir().exists(filename))
+            return info.dir().filePath(filename);
+    }
+    return filePath;
+}
+
+QString Util::trcString(int trc)
+{
+    QString trcString = QObject::tr("unknown (%1)").arg(trc);
+    switch (trc) {
+    case 0:
+        trcString = QObject::tr("NA");
+        break;
+    case 1:
+        trcString = "ITU-R BT.709";
+        break;
+    case 6:
+        trcString = "ITU-R BT.601";
+        break;
+    case 7:
+        trcString = "SMPTE ST240";
+        break;
+    case 11:
+        trcString = "IEC 61966-2-4";
+        break;
+    case 14:
+        trcString = "ITU-R BT.2020";
+        break;
+    case 15:
+        trcString = "ITU-R BT.2020";
+        break;
+    case 16:
+        trcString = "SMPTE ST2084 (PQ)";
+        break;
+    case 17:
+        trcString = "SMPTE ST428";
+        break;
+    case 18:
+        trcString = "ARIB B67 (HLG)";
+        break;
+    }
+    return trcString;
+}
+
+bool Util::trcIsCompatible(int trc)
+{
+    // Transfer characteristics > SMPTE240M Probably need conversion except IEC61966-2-4 is OK
+    return trc <= 7 || trc == 11 || trc == 18;
+}
+
+QString Util::getConversionAdvice(Mlt::Producer *producer)
+{
+    QString advice;
+    producer->probe();
+    QString resource = Util::GetFilenameFromProducer(producer);
+    int trc = producer->get_int("meta.media.color_trc");
+    if (!Util::trcIsCompatible(trc)) {
+        QString trcString = Util::trcString(trc);
+        LOG_INFO() << resource << "Probable HDR" << trcString;
+        advice = QObject::tr("This file uses color transfer characteristics %1, which may result in incorrect colors or brightness in Shotcut.").arg(
+                     trcString);
+    } else if (producer->get_int("meta.media.variable_frame_rate")) {
+        LOG_INFO() << resource << "is variable frame rate";
+        advice = QObject::tr("This file is variable frame rate, which is not reliable for editing.");
+    } else if (QFile::exists(resource) && !MLT.isSeekable(producer)) {
+        LOG_INFO() << resource << "is not seekable";
+        advice = QObject::tr("This file does not support seeking and cannot be used for editing.");
+    } else if (QFile::exists(resource) && resource.endsWith(".m2t")) {
+        LOG_INFO() << resource << "is HDV";
+        advice = QObject::tr("This file format (HDV) is not reliable for editing.");
+    }
+    return advice;
+}
+
+mlt_color Util::mltColorFromQColor(const QColor &color)
+{
+    return mlt_color {
+        static_cast<uint8_t>(color.red()),
+        static_cast<uint8_t>(color.green()),
+        static_cast<uint8_t>(color.blue()),
+        static_cast<uint8_t>(color.alpha())
+    };
+}
