@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2022 Meltytech, LLC
+ * Copyright (c) 2012-2023 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -114,8 +114,7 @@ void ImageProducerWidget::setProducer(Mlt::Producer *p)
         ui->repeatSpinBox->setValue(m_producer->get_int("ttl"));
     ui->sequenceCheckBox->setChecked(m_producer->get_int(kShotcutSequenceProperty));
     ui->repeatSpinBox->setEnabled(m_producer->get_int(kShotcutSequenceProperty));
-    ui->durationSpinBox->setEnabled(!p->get(kMultitrackItemProperty)
-                                    && !m_producer->get_int(kShotcutSequenceProperty));
+    ui->durationSpinBox->setEnabled(!m_producer->get_int(kShotcutSequenceProperty));
     ui->defaultDurationButton->setEnabled(ui->durationSpinBox->isEnabled());
     ui->notesTextEdit->setPlainText(QString::fromUtf8(m_producer->get(kCommentProperty)));
 }
@@ -368,7 +367,8 @@ static QString GetFilenameFromProducer(Mlt::Producer *producer, bool useOriginal
 
 void ImageProducerWidget::on_actionCopyFullFilePath_triggered()
 {
-    qApp->clipboard()->setText(GetFilenameFromProducer(producer()));
+    auto s = GetFilenameFromProducer(producer());
+    qApp->clipboard()->setText(QDir::toNativeSeparators(s));
 }
 
 void ImageProducerWidget::on_actionOpenFolder_triggered()
