@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2021 Meltytech, LLC
+ * Copyright (c) 2016-2023 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@ QRect PlaylistIconView::visualRect(const QModelIndex &index) const
     int row = index.row() / m_itemsPerRow;
     int col = index.row() % m_itemsPerRow;
     return QRect(col * m_gridSize.width(), row * m_gridSize.height(),
-            m_gridSize.width(), m_gridSize.height());
+                 m_gridSize.width(), m_gridSize.height());
 }
 
 void PlaylistIconView::rowsInserted(const QModelIndex &parent, int start, int end)
@@ -61,14 +61,16 @@ void PlaylistIconView::rowsAboutToBeRemoved(const QModelIndex &parent, int start
     viewport()->update();
 }
 
-void PlaylistIconView::dataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight, const QVector<int> &roles)
+void PlaylistIconView::dataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight,
+                                   const QVector<int> &roles)
 {
     QAbstractItemView::dataChanged(topLeft, bottomRight, roles);
     updateSizes();
     viewport()->update();
 }
 
-void PlaylistIconView::selectionChanged(const QItemSelection& selected, const QItemSelection& deselected)
+void PlaylistIconView::selectionChanged(const QItemSelection &selected,
+                                        const QItemSelection &deselected)
 {
     QAbstractItemView::selectionChanged(selected, deselected);
     viewport()->update();
@@ -126,13 +128,16 @@ void PlaylistIconView::setSelection(const QRect &rect, QItemSelectionModel::Sele
         return;
     }
     if (m_isToggleSelect) {
-        command = QItemSelectionModel::Toggle;
+        command = QItemSelectionModel::Select;
         selectionModel()->select(indexAt(rect.bottomRight()), command);
         return;
     } else if (m_isRangeSelect && topLeft.isValid()) {
         QModelIndex bottomRight = indexAt(rect.bottomRight());
         selectionModel()->select(QItemSelection(topLeft, bottomRight), command);
         return;
+    } else if (topLeft.isValid()) {
+        selectionModel()->select(indexAt(rect.topLeft()), command);
+        return;
     }
     m_pendingSelect = indexAt(rect.topLeft());
 }
@@ -149,7 +154,7 @@ void PlaylistIconView::currentChanged(const QModelIndex &current, const QModelIn
     QAbstractItemView::currentChanged(current, previous);
 }
 
-void PlaylistIconView::paintEvent(QPaintEvent*)
+void PlaylistIconView::paintEvent(QPaintEvent *)
 {
     QPainter painter(viewport());
     QPalette pal(palette());
@@ -162,7 +167,7 @@ void PlaylistIconView::paintEvent(QPaintEvent*)
     if (!model())
         return;
 
-    QAbstractItemModel * m = model();
+    QAbstractItemModel *m = model();
     QRect dragIndicator;
 
     for (int row = 0; row <= m->rowCount() / m_itemsPerRow; row++) {
@@ -174,7 +179,7 @@ void PlaylistIconView::paintEvent(QPaintEvent*)
                 break;
 
             QRect itemRect(col * m_gridSize.width(), row * m_gridSize.height() - verticalScrollBar()->value(),
-                    m_gridSize.width(), m_gridSize.height());
+                           m_gridSize.width(), m_gridSize.height());
 
             if (itemRect.bottom() < 0 || itemRect.top() > this->height())
                 continue;
@@ -222,7 +227,7 @@ void PlaylistIconView::paintEvent(QPaintEvent*)
             }
             painter.setPen(pal.color(QPalette::WindowText));
             painter.drawText(textRect, Qt::AlignCenter,
-                    painter.fontMetrics().elidedText(nameParts.first(), Qt::ElideMiddle, textRect.width()));
+                             painter.fontMetrics().elidedText(nameParts.first(), Qt::ElideMiddle, textRect.width()));
 
             if (!m_draggingOverPos.isNull() && itemRect.contains(m_draggingOverPos)) {
                 QAbstractItemView::DropIndicatorPosition dropPos =
@@ -254,7 +259,7 @@ void PlaylistIconView::mouseReleaseEvent(QMouseEvent *event)
 
 void PlaylistIconView::dragMoveEvent(QDragMoveEvent *e)
 {
-    m_draggingOverPos = e->pos();
+    m_draggingOverPos = e->position().toPoint();
     QAbstractItemView::dragMoveEvent(e);
 }
 
@@ -268,11 +273,11 @@ void PlaylistIconView::dropEvent(QDropEvent *event)
 {
     m_draggingOverPos = QPoint();
 
-    QModelIndex index = indexAt(event->pos());
+    QModelIndex index = indexAt(event->position().toPoint());
     QRect rectAtDropPoint = visualRect(index);
 
     QAbstractItemView::DropIndicatorPosition dropPos =
-        position(event->pos(), rectAtDropPoint, index);
+        position(event->position().toPoint(), rectAtDropPoint, index);
     if (dropPos == QAbstractItemView::BelowItem)
         index = index.sibling(index.row() + 1, index.column());
 
@@ -292,14 +297,14 @@ void PlaylistIconView::resizeEvent(QResizeEvent *event)
     QAbstractItemView::resizeEvent(event);
 }
 
-void PlaylistIconView::setModel(QAbstractItemModel* model)
+void PlaylistIconView::setModel(QAbstractItemModel *model)
 {
     QAbstractItemView::setModel(model);
     updateSizes();
     viewport()->update();
 }
 
-void PlaylistIconView::keyPressEvent(QKeyEvent* event)
+void PlaylistIconView::keyPressEvent(QKeyEvent *event)
 {
     QAbstractItemView::keyPressEvent(event);
     event->ignore();
@@ -314,7 +319,8 @@ void PlaylistIconView::keyReleaseEvent(QKeyEvent *event)
     resetMultiSelect();
 }
 
-QAbstractItemView::DropIndicatorPosition PlaylistIconView::position(const QPoint &pos, const QRect &rect, const QModelIndex &index) const
+QAbstractItemView::DropIndicatorPosition PlaylistIconView::position(const QPoint &pos,
+                                                                    const QRect &rect, const QModelIndex &index) const
 {
     Q_UNUSED(index);
     if (pos.x() < rect.center().x())
@@ -325,8 +331,7 @@ QAbstractItemView::DropIndicatorPosition PlaylistIconView::position(const QPoint
 
 void PlaylistIconView::updateSizes()
 {
-    if (!model() || !model()->rowCount())
-    {
+    if (!model() || !model()->rowCount()) {
         verticalScrollBar()->setRange(0, 0);
         return;
     }
@@ -349,7 +354,8 @@ void PlaylistIconView::updateSizes()
     if (!verticalScrollBar())
         return;
 
-    verticalScrollBar()->setRange(0, m_gridSize.height() * model()->rowCount() / m_itemsPerRow - height() + m_gridSize.height());
+    verticalScrollBar()->setRange(0,
+                                  m_gridSize.height() * model()->rowCount() / m_itemsPerRow - height() + m_gridSize.height());
     viewport()->update();
 }
 
