@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2020-2022 Meltytech, LLC
+ * Copyright (c) 2020-2024 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -43,6 +43,10 @@ enum {
 
 static const int minTransitionFrames = 2;
 
+static const int randomIndex = 0;
+static const int cutIndex = 1;
+static const int dissolveIndex = 2;
+
 SlideshowGeneratorWidget::SlideshowGeneratorWidget(Mlt::Playlist *clips, QWidget *parent)
     : QWidget(parent)
     , m_clips(clips)
@@ -58,7 +62,7 @@ SlideshowGeneratorWidget::SlideshowGeneratorWidget(Mlt::Playlist *clips, QWidget
     m_clipDurationSpinner->setDecimals(1);
     m_clipDurationSpinner->setMinimum(0.2);
     m_clipDurationSpinner->setMaximum(3600 * 4);
-    m_clipDurationSpinner->setValue(10);
+    m_clipDurationSpinner->setValue(Settings.slideshowClipDuration(10.0));
     connect(m_clipDurationSpinner, SIGNAL(valueChanged(double)), this, SLOT(on_parameterChanged()));
     grid->addWidget(m_clipDurationSpinner, 0, 1);
 
@@ -74,7 +78,8 @@ SlideshowGeneratorWidget::SlideshowGeneratorWidget(Mlt::Playlist *clips, QWidget
         }
     }
     m_aspectConversionCombo->setToolTip(tr("Choose an aspect ratio conversion method."));
-    m_aspectConversionCombo->setCurrentIndex(ASPECT_CONVERSION_CROP_CENTER);
+    m_aspectConversionCombo->setCurrentIndex(Settings.slideshowAspectConversion(
+                                                 ASPECT_CONVERSION_CROP_CENTER));
     connect(m_aspectConversionCombo, SIGNAL(currentIndexChanged(int)), this,
             SLOT(on_parameterChanged()));
     grid->addWidget(m_aspectConversionCombo, 1, 1);
@@ -86,7 +91,7 @@ SlideshowGeneratorWidget::SlideshowGeneratorWidget(Mlt::Playlist *clips, QWidget
     m_zoomPercentSpinner->setSuffix(" %");
     m_zoomPercentSpinner->setMinimum(-50);
     m_zoomPercentSpinner->setMaximum(50);
-    m_zoomPercentSpinner->setValue(10);
+    m_zoomPercentSpinner->setValue(Settings.slideshowZoomPercent(10));
     connect(m_zoomPercentSpinner, SIGNAL(valueChanged(int)), this, SLOT(on_parameterChanged()));
     grid->addWidget(m_zoomPercentSpinner, 2, 1);
 
@@ -98,7 +103,7 @@ SlideshowGeneratorWidget::SlideshowGeneratorWidget(Mlt::Playlist *clips, QWidget
     m_transitionDurationSpinner->setDecimals(1);
     m_transitionDurationSpinner->setMinimum(0);
     m_transitionDurationSpinner->setMaximum(10);
-    m_transitionDurationSpinner->setValue(2);
+    m_transitionDurationSpinner->setValue(Settings.slideshowTransitionDuration(2.0));
     connect(m_transitionDurationSpinner, SIGNAL(valueChanged(double)), this,
             SLOT(on_parameterChanged()));
     grid->addWidget(m_transitionDurationSpinner, 3, 1);
@@ -107,6 +112,7 @@ SlideshowGeneratorWidget::SlideshowGeneratorWidget(Mlt::Playlist *clips, QWidget
     m_transitionStyleCombo = new QComboBox();
     m_transitionStyleCombo->setMaximumWidth(350);
     m_transitionStyleCombo->addItem(tr("Random"));
+    m_transitionStyleCombo->addItem(tr("Cut"));
     m_transitionStyleCombo->addItem(tr("Dissolve"));
     m_transitionStyleCombo->addItem(tr("Bar Horizontal"));
     m_transitionStyleCombo->addItem(tr("Bar Vertical"));
@@ -134,7 +140,7 @@ SlideshowGeneratorWidget::SlideshowGeneratorWidget(Mlt::Playlist *clips, QWidget
         m_transitionStyleCombo->addItem(QFileInfo(s).fileName(), s);
     }
     m_transitionStyleCombo->setToolTip(tr("Choose a transition effect."));
-    m_transitionStyleCombo->setCurrentIndex(1);
+    m_transitionStyleCombo->setCurrentIndex(Settings.slideshowTransitionStyle(dissolveIndex));
     connect(m_transitionStyleCombo, SIGNAL(currentIndexChanged(int)), this,
             SLOT(on_parameterChanged()));
     grid->addWidget(m_transitionStyleCombo, 4, 1);
@@ -145,7 +151,7 @@ SlideshowGeneratorWidget::SlideshowGeneratorWidget(Mlt::Playlist *clips, QWidget
     m_softnessSpinner->setSuffix(" %");
     m_softnessSpinner->setMaximum(100);
     m_softnessSpinner->setMinimum(0);
-    m_softnessSpinner->setValue(20);
+    m_softnessSpinner->setValue(Settings.slideshowTransitionSoftness(20));
     connect(m_softnessSpinner, SIGNAL(valueChanged(int)), this, SLOT(on_parameterChanged()));
     grid->addWidget(m_softnessSpinner, 5, 1);
 
@@ -238,6 +244,13 @@ Mlt::Playlist *SlideshowGeneratorWidget::getSlideshow()
         }
     }
 
+    Settings.setSlideshowClipDuration(m_config.clipDuration);
+    Settings.setSlideshowAspectConversion(m_config.aspectConversion);
+    Settings.setSlideshowZoomPercent(m_config.zoomPercent);
+    Settings.setSlideshowTransitionDuration(m_config.transitionDuration);
+    Settings.setSlideshowTransitionStyle(m_config.transitionStyle);
+    Settings.setSlideshowTransitionSoftness(m_config.transitionSoftness);
+
     return slideshow;
 }
 
@@ -266,7 +279,10 @@ void SlideshowGeneratorWidget::attachAffineFilter(SlideshowConfig &config, Mlt::
     double destDar = MLT.profile().dar();
     double sourceW = producer->get_double("meta.media.width");
     double sourceH = producer->get_double("meta.media.height");
-    double sourceAr = producer->get_double("aspect_ratio");
+    double sourceAr = producer->get_double("meta.media.aspect_ratio");
+    if (!sourceAr) {
+        sourceAr = producer->get_double("aspect_ratio");
+    }
     double sourceDar = destDar;
     if (sourceW && sourceH && sourceAr) {
         sourceDar = sourceW * sourceAr / sourceH;
@@ -342,16 +358,26 @@ void SlideshowGeneratorWidget::attachAffineFilter(SlideshowConfig &config, Mlt::
         beginRect.h = beginRect.h + (beginScale * beginRect.h);
     }
 
-    Mlt::Filter filter(MLT.profile(), "affine");
-    filter.anim_set("transition.rect", beginRect, 0);
-    filter.anim_set("transition.rect", endRect, endPosition);
-    filter.set("transition.fill", 1);
-    filter.set("transition.distort", 0);
-    filter.set("transition.valign", "middle");
-    filter.set("transition.halign", "center");
-    filter.set("transition.threads", 0);
-    filter.set("background", "color:#000000");
-    filter.set(kShotcutFilterProperty, "affineSizePosition");
+    Mlt::Filter filter(MLT.profile(), Settings.playerGPU() ? "movit.rect" : "affine");
+    if (Settings.playerGPU()) {
+        filter.anim_set("rect", beginRect, 0);
+        filter.anim_set("rect", endRect, endPosition);
+        filter.set("fill", 1);
+        filter.set("distort", 0);
+        filter.set("valign", "middle");
+        filter.set("halign", "center");
+        filter.set(kShotcutFilterProperty, "movitSizePosition");
+    } else {
+        filter.anim_set("transition.rect", beginRect, 0);
+        filter.anim_set("transition.rect", endRect, endPosition);
+        filter.set("transition.fill", 1);
+        filter.set("transition.distort", 0);
+        filter.set("transition.valign", "middle");
+        filter.set("transition.halign", "center");
+        filter.set("transition.threads", 0);
+        filter.set("background", "color:#000000");
+        filter.set(kShotcutFilterProperty, "affineSizePosition");
+    }
     filter.set(kShotcutAnimInProperty, producer->frames_to_time(endPosition + 1, mlt_time_clock));
     filter.set(kShotcutAnimOutProperty, producer->frames_to_time(0, mlt_time_clock));
     producer->attach(filter);
@@ -372,7 +398,10 @@ void SlideshowGeneratorWidget::attachBlurFilter(SlideshowConfig &config, Mlt::Pr
     double destDar = MLT.profile().dar();
     double sourceW = producer->get_double("meta.media.width");
     double sourceH = producer->get_double("meta.media.height");
-    double sourceAr = producer->get_double("aspect_ratio");
+    double sourceAr = producer->get_double("meta.media.aspect_ratio");
+    if (!sourceAr) {
+        sourceAr = producer->get_double("aspect_ratio");
+    }
     double sourceDar = destDar;
     if ( sourceW && sourceH && sourceAr ) {
         sourceDar = sourceW * sourceAr / sourceH;
@@ -404,23 +433,30 @@ void SlideshowGeneratorWidget::applyLumaTransitionProperties(Mlt::Transition *lu
 {
     int index = config.transitionStyle;
 
-    if (index == 0) {
-        // Random: pick any number other than 0
-        index = rand() % m_transitionStyleCombo->count() + 1;
+    if (index == randomIndex) {
+        // Random: pick any number other than randomIndex (0) or cutIndex (1)
+        index = rand() % (m_transitionStyleCombo->count() - 2) + 2;
     }
 
-    if (index == 1) {
-        // Dissolve
+    if (index == cutIndex) {
+        luma->set("resource", "color:#7f7f7f");
+        luma->set("softness", 0);
+    } else if (index == dissolveIndex) {
         luma->set("resource", "");
-    } else if (index <= 23) {
-        luma->set("resource", QString("%luma%1.pgm").arg(index - 1, 2, 10,
+        luma->set("softness", 0);
+    } else if (index <= 24) {
+        luma->set("resource", QString("%luma%1.pgm").arg(index - 2, 2, 10,
                                                          QChar('0')).toLatin1().constData());
+        luma->set("softness", config.transitionSoftness / 100.0);
     } else {
         luma->set("resource", m_transitionStyleCombo->itemData(index).toString().toUtf8().constData());
+        luma->set("softness", config.transitionSoftness / 100.0);
     }
-    luma->set("softness", config.transitionSoftness / 100.0);
     luma->set("progressive", 1);
-    if (!Settings.playerGPU()) luma->set("alpha_over", 1);
+    if (!Settings.playerGPU()) {
+        luma->set("alpha_over", 1);
+        luma->set("fix_background_alpha", 1);
+    }
 }
 
 void SlideshowGeneratorWidget::on_parameterChanged()
@@ -428,10 +464,13 @@ void SlideshowGeneratorWidget::on_parameterChanged()
     if (m_transitionDurationSpinner->value() > m_clipDurationSpinner->value() / 2 ) {
         m_transitionDurationSpinner->setValue(m_clipDurationSpinner->value() / 2);
     }
-    if (m_transitionDurationSpinner->value() == 0) {
+    if (m_transitionDurationSpinner->value() == randomIndex) {
         m_transitionStyleCombo->setEnabled(false);
         m_softnessSpinner->setEnabled(false);
-    } else if (m_transitionStyleCombo->currentIndex() == 1) {
+    } else if (m_transitionStyleCombo->currentIndex() == cutIndex) {
+        m_transitionStyleCombo->setEnabled(true);
+        m_softnessSpinner->setEnabled(false);
+    } else if (m_transitionStyleCombo->currentIndex() == dissolveIndex) {
         m_transitionStyleCombo->setEnabled(true);
         m_softnessSpinner->setEnabled(false);
     } else {
@@ -440,7 +479,8 @@ void SlideshowGeneratorWidget::on_parameterChanged()
     }
 
     m_preview->stop();
-    m_preview->showText(tr("Generating Preview..."));
+    m_preview->showText(Settings.playerGPU() ? tr("Preview Not Available") :
+                        tr("Generating Preview..."));
     m_mutex.lock();
     m_refreshPreview = true;
     m_config.clipDuration = m_clipDurationSpinner->value();
@@ -451,7 +491,7 @@ void SlideshowGeneratorWidget::on_parameterChanged()
     m_config.transitionSoftness = m_softnessSpinner->value();
     if (m_future.isFinished() || m_future.isCanceled()) {
         // Generate the preview producer in another thread because it can take some time
-        m_future = QtConcurrent::run(this, &SlideshowGeneratorWidget::generatePreviewSlideshow);
+        m_future = QtConcurrent::run(&SlideshowGeneratorWidget::generatePreviewSlideshow, this);
     }
     m_mutex.unlock();
 }
